export class IgxCollection {
    constructor() {
        this._isIgxCollection = true;
        this._inner = null;
        this._innerColl = null;
        this._innerColl = this._createInnerColl();
    }
    item(index, value) {
        if (this._innerColl != null) {
            return this._innerColl.get(index);
        }
        else {
            if (value) {
                let innerValue = null;
                if (value._implementation) {
                    innerValue = value._implementation;
                }
                else {
                    innerValue = value;
                }
                this._inner.item(index, innerValue);
            }
            else {
                let item = this._inner.item(index);
                if (item.externalObject) {
                    return item.externalObject;
                }
                return item;
            }
        }
    }
    indexOf(item) {
        if (this._innerColl != null) {
            return this._innerColl.indexOf(item);
        }
        else {
            let actualItem = item;
            if (actualItem._implementation) {
                actualItem = actualItem._implementation;
            }
            return this._inner.indexOf(actualItem);
        }
    }
    insert(index, item) {
        if (this._innerColl != null) {
            this._innerColl.add1(index, item);
        }
        else {
            let actualItem = item;
            if (actualItem._implementation) {
                actualItem = actualItem._implementation;
            }
            this._inner.insert(index, actualItem);
        }
    }
    removeAt(index) {
        if (this._innerColl != null) {
            this._innerColl.remove(index);
        }
        else {
            this._inner.removeAt(index);
        }
    }
    get count() {
        if (this._innerColl != null) {
            return this._innerColl.size();
        }
        else {
            return this._inner.count;
        }
    }
    add(item) {
        if (this._innerColl != null) {
            this._innerColl.add(item);
        }
        else {
            let actualItem = item;
            if (actualItem._implementation) {
                actualItem = actualItem._implementation;
            }
            this._inner.add(actualItem);
        }
    }
    clear() {
        if (this._innerColl != null) {
            this._innerColl.clear();
        }
        else {
            this._inner.clear();
        }
    }
    contains(item) {
        if (this._innerColl != null) {
            return this._innerColl.all.contains(item);
        }
        else {
            let actualItem = item;
            if (actualItem._implementation) {
                actualItem = actualItem._implementation;
            }
            return this._inner.contains(actualItem);
        }
    }
    remove(item) {
        if (this._innerColl != null) {
            return this._innerColl.remove1(item);
        }
        else {
            let actualItem = item;
            if (actualItem._implementation) {
                actualItem = actualItem._implementation;
            }
            return this._inner.remove(actualItem);
        }
    }
    *[Symbol.iterator]() {
        for (let i = 0; i < this.count; i++) {
            let item = this.item(i);
            if (item.externalObject) {
                item = item.externalObject;
            }
            yield item;
        }
    }
    _setSyncTarget(list) {
        if (this._innerColl != null) {
            this._innerColl.syncTarget = list;
        }
    }
    _fromInner(inner) {
        this._inner = inner;
        this._innerColl = null;
        return this;
    }
    _ensureOuter(item) {
        return item;
    }
    _splitOuter(item) {
        if (item == null) {
            return [];
        }
        if (item.indexOf(",") == -1) {
            return [item];
        }
        return item.split(",");
    }
    _fromOuter(outer) {
        if (outer._isIgxCollection) {
            return outer;
        }
        if (Array.isArray(outer)) {
            for (let i = 0; i < outer.length; i++) {
                this.add(this._ensureOuter(outer[i]));
            }
            return this;
        }
        let split = this._splitOuter(outer);
        for (let i = 0; i < split.length; i++) {
            this.add(this._ensureOuter(split[i]));
        }
        return this;
    }
}
//# sourceMappingURL=IgxCollection.js.map