import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from './igx-strategy-based-indicator-component';
import { IgxFinancialIndicatorComponent } from './igx-financial-indicator-component';
import { IgxFinancialSeriesComponent } from './igx-financial-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { BollingerBandWidthIndicator } from "./BollingerBandWidthIndicator";
/**
 * Represents a IgxDataChartComponent Bollinger Bandwidth indicator series.
 * Represents the normalized width of the Bollinger bands for each provided value.
 * For more info see: BollingerBandsOverlay
 * Default required members: High, Low, Close
*/
export const IgxBollingerBandWidthIndicatorComponent_PROVIDERS = [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(() => IgxBollingerBandWidthIndicatorComponent) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(() => IgxBollingerBandWidthIndicatorComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandWidthIndicatorComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandWidthIndicatorComponent) }];
export class IgxBollingerBandWidthIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new BollingerBandWidthIndicator();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the moving average period for the Bollinger Band Width Indicator.
         * The typical, and initial, value for CCI periods is 20.
        */
    get period() {
        return this.i.qb;
    }
    set period(v) {
        this.i.qb = +v;
    }
    /**
         * Gets or sets the multiplier for the Bollinger Band width.
         * The typical, and initial, value for Bollinger Band width multiplier is 2.
        */
    get multiplier() {
        return this.i.qa;
    }
    set multiplier(v) {
        this.i.qa = +v;
    }
}
IgxBollingerBandWidthIndicatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-bollinger-band-width-indicator',
                template: ``,
                providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(() => IgxBollingerBandWidthIndicatorComponent) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(() => IgxBollingerBandWidthIndicatorComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandWidthIndicatorComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandWidthIndicatorComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxBollingerBandWidthIndicatorComponent.ctorParameters = () => [];
IgxBollingerBandWidthIndicatorComponent.propDecorators = {
    "period": [{ type: Input },],
    "multiplier": [{ type: Input },],
};
//# sourceMappingURL=igx-bollinger-band-width-indicator-component.js.map