import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxCategoryAxisBaseComponent } from './igx-category-axis-base-component';
import { IgxAxisComponent } from './igx-axis-component';
import { CategoryAngleAxis } from "./CategoryAngleAxis";
/**
 * Represents a IgxDataChartComponent category angle axis. Useful for displaying radial categories.
*/
export const IgxCategoryAngleAxisComponent_PROVIDERS = [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryAngleAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryAngleAxisComponent) }];
export class IgxCategoryAngleAxisComponent extends IgxCategoryAxisBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CategoryAngleAxis();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Checks if the axis is of angular type
        */
    get isAngular() {
        return this.i.bs;
    }
    /**
         * Indicates the angle in degress that the chart's 0th angle should be offset.
        */
    get startAngleOffset() {
        return this.i.ku;
    }
    set startAngleOffset(v) {
        this.i.ku = +v;
    }
    /**
         * Gets or sets the frequency of displayed labels.
         * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        */
    get interval() {
        return this.i.kr;
    }
    set interval(v) {
        this.i.kr = +v;
    }
    /**
         * Gets the effective value for the current Interval.
        */
    get actualInterval() {
        return this.i.kl;
    }
    /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        */
    get minorInterval() {
        return this.i.ks;
    }
    set minorInterval(v) {
        this.i.ks = +v;
    }
    /**
         * Gets the effective value for the current MinorInterval.
        */
    get actualMinorInterval() {
        return this.i.km;
    }
    /**
         * Gets the scaled angle in radians from the raw axis value.
        
        * @param unscaledAngle  * The raw axis value.
        */
    getScaledAngle(unscaledAngle) {
        let iv = this.i.getScaledAngle(unscaledAngle);
        return (iv);
    }
    /**
         * Gets the raw axis value from the scaled angle in radians.
        
        */
    getUnscaledAngle(scaledAngle) {
        let iv = this.i.getUnscaledAngle(scaledAngle);
        return (iv);
    }
}
IgxCategoryAngleAxisComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-category-angle-axis',
                template: ``,
                providers: [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryAngleAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryAngleAxisComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCategoryAngleAxisComponent.ctorParameters = () => [];
IgxCategoryAngleAxisComponent.propDecorators = {
    "startAngleOffset": [{ type: Input },],
    "interval": [{ type: Input },],
    "minorInterval": [{ type: Input },],
};
//# sourceMappingURL=igx-category-angle-axis-component.js.map