import { EventEmitter, Output, TemplateRef, Component, ViewContainerRef, Injector, ComponentFactoryResolver, Renderer2, ViewChild, QueryList, ElementRef, Inject, Input, NgZone, ChangeDetectionStrategy, ViewChildren } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { AngularRenderer, AngularWrapper } from './angular-renderer';
import { TypeRegistrar } from './type';
import { FinancialChart } from './FinancialChart';
import { FinancialChartType, FinancialChartType_$type } from './FinancialChartType';
import { fromBrushCollection, toBrushCollection, ensureEnum, ensureBool } from './componentUtil';
import { IgxXYChartComponent } from './igx-xy-chart-component';
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
import { DataSeriesType } from './DataSeriesType';
import { DataContext } from './igx-data-context';
import { FinancialChartVolumeType, FinancialChartVolumeType_$type } from './FinancialChartVolumeType';
import { FinancialChartXAxisMode, FinancialChartXAxisMode_$type } from './FinancialChartXAxisMode';
import { FinancialChartYAxisMode, FinancialChartYAxisMode_$type } from './FinancialChartYAxisMode';
import { HorizontalAlignment, HorizontalAlignment_$type } from './HorizontalAlignment';
import { AxisLabelsLocation, AxisLabelsLocation_$type } from './AxisLabelsLocation';
import { FinancialChartZoomSliderType, FinancialChartZoomSliderType_$type } from './FinancialChartZoomSliderType';
import { IgxFinancialChartDefaultTemplatesComponent } from './igx-financial-chart-default-templates';
import { IgxTemplateContentComponent } from './igx-template-content-component';
import { delegateCombine } from './type';
import { FinancialIndicatorTypeCollection } from './igx-financial-indicator-type-collection';
import { FinancialIndicatorTypeCollection as FinancialIndicatorTypeCollection_internal } from './FinancialIndicatorTypeCollection';
import { SyncableObservableCollection$1 } from './SyncableObservableCollection$1';
import { FinancialIndicatorType_$type } from './FinancialIndicatorType';
import { FinancialOverlayTypeCollection } from './igx-financial-overlay-type-collection';
import { FinancialOverlayTypeCollection as FinancialOverlayTypeCollection_internal } from './FinancialOverlayTypeCollection';
import { FinancialOverlayType_$type } from './FinancialOverlayType';
import { IndicatorDisplayTypeCollection } from './igx-indicator-display-type-collection';
import { IndicatorDisplayTypeCollection as IndicatorDisplayTypeCollection_internal } from './IndicatorDisplayTypeCollection';
import { IndicatorDisplayType_$type } from './IndicatorDisplayType';
import { FinancialChartRangeSelectorOptionCollection } from './igx-financial-chart-range-selector-option-collection';
import { FinancialChartRangeSelectorOptionCollection as FinancialChartRangeSelectorOptionCollection_internal } from './FinancialChartRangeSelectorOptionCollection';
import { FinancialChartRangeSelectorOption_$type } from './FinancialChartRangeSelectorOption';
import { FinancialChartCustomIndicatorArgs } from './igx-financial-chart-custom-indicator-args';
import { CustomIndicatorNameCollection as CustomIndicatorNameCollection_internal } from './CustomIndicatorNameCollection';
import { CustomIndicatorNameCollection } from './igx-custom-indicator-name-collection';
import { String_$type } from './type';
export const IgxFinancialChartComponent_PROVIDERS = [];
/**
 * Represents a chart with an ordinal X-axis and a numeric Y-axis.
*
* **Ignite UI for Angular Financial Chart** - [Documentation](http://linkToSomewhere/FinancialChart/Overview)
*
* The Ignite UI Financial Chart is a lightweight, highly performant chart. It can be easily configured to display category data using an extremely simple and intuitive API. It offers multiple ways for the user to visualize data, including several display modes for price and volume, and many financial indicators.
*
* Example:
*
* ```html
* <igx-financial-chart [dataSource]="data"
* 					 width="850px" height="600px">
* </igx-financial-chart>
* ```
*/
export class IgxFinancialChartComponent extends IgxXYChartComponent {
    constructor(renderer, _elRef, document, ngZone, injector, componentFactoryResolver) {
        super();
        this.renderer = renderer;
        this._elRef = _elRef;
        this.document = document;
        this.ngZone = ngZone;
        this.injector = injector;
        this.componentFactoryResolver = componentFactoryResolver;
        this._wrapper = null;
        this._dataSource = null;
        this._defaultTooltips = null;
        this._indicatorTypes = null;
        this._overlayTypes = null;
        this._indicatorDisplayTypes = null;
        this._rangeSelectorOptions = null;
        this._customIndicatorNames = null;
        this._applyCustomIndicators = null;
        this._zoneRunner = (act) => ngZone.run(act);
        this.container = renderer.createElement("div");
        renderer.appendChild(_elRef.element.nativeElement, this.container);
        renderer.setStyle(this.container, "display", "block");
        renderer.setStyle(this.container, "width", "100%");
        renderer.setStyle(this.container, "height", "100%");
        var root;
        root = this.container;
        if (this.container != null) {
            root = this.container;
        }
        var ren = new AngularRenderer(root, this.renderer, this.document, this.ngZone, true, DataChartStylingDefaults);
        this._wrapper = ren;
        var chart = this.i;
        this._chart = chart;
        if (chart.xAxis) {
            this.rewrapAxis(chart.xAxis);
        }
        if (chart.yAxis) {
            this.rewrapAxis(chart.yAxis);
        }
        if (chart.volumeAxis) {
            this.rewrapAxis(chart.volumeAxis);
        }
        if (chart.volumeXAxis) {
            this.rewrapAxis(chart.volumeXAxis);
        }
        if (chart.indicatorAxis) {
            this.rewrapAxis(chart.indicatorAxis);
        }
        if (chart.indicatorXAxis) {
            this.rewrapAxis(chart.indicatorXAxis);
        }
        if (chart.zoomSliderAxis) {
            this.rewrapAxis(chart.zoomSliderAxis);
        }
        if (chart.zoomSliderXAxis) {
            this.rewrapAxis(chart.zoomSliderXAxis);
        }
        chart.provideContainer(ren);
        this.bindData();
        chart.notifyResized();
        ren.addSizeWatcher(() => {
            this._checkToolbarSize();
            this._chart.notifyResized();
        });
    }
    set height(value) {
        this._height = value;
        this.renderer.setStyle(this._elRef.element.nativeElement, "height", value);
        this._chart.notifyResized();
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        this.renderer.setStyle(this._elRef.element.nativeElement, "width", value);
        this._chart.notifyResized();
    }
    get width() {
        return this._width;
    }
    _checkToolbarSize() {
        if (this._toolbarElement) {
            let start = this._toolbarElement.nativeElement;
            if (start.children.length == 1) {
                start = start.children[0];
            }
            let toolbarRoot = start.querySelector(".financialChartToolbar");
            let rootRect = toolbarRoot.getBoundingClientRect();
            let hideRemaining = false;
            for (let i = 0; i < toolbarRoot.children.length; i++) {
                let child = toolbarRoot.children[i];
                if (child.nodeType == Node.ELEMENT_NODE) {
                    if (!hideRemaining) {
                        child.style.display = "";
                    }
                    let childRect = child.getBoundingClientRect();
                    if (hideRemaining ||
                        childRect.left + childRect.width >
                            rootRect.left + rootRect.width) {
                        child.style.display = "none";
                        hideRemaining = true;
                    }
                    else {
                        child.style.display = "";
                    }
                }
            }
        }
    }
    ngOnDestroy() {
        this._chart.destroy();
        this._wrapper.destroy();
    }
    onDocumentClick(ev) {
        let classList = ev.target.classList;
        let classes = [];
        if (classList) {
            for (let i = 0; i < classList.length; i++) {
                classes.push(classList[i]);
            }
        }
        this._chart.onDocumentClick(classes);
    }
    rewrapAxis(axis) {
        let axisName = axis.$type.name;
        let componentName = "Igx" + axisName + "Component";
        if (TypeRegistrar.isRegistered(componentName)) {
            let x = TypeRegistrar.create(componentName);
            x._implementation = axis;
            axis.externalObject = x;
        }
        else {
            throw new Error("Axis type not loaded: " + componentName);
        }
    }
    createImplementation() {
        return new FinancialChart();
    }
    get i() {
        return this._implementation;
    }
    createSeriesComponent(type) {
        if (TypeRegistrar.isRegistered(type)) {
            let s = TypeRegistrar.create(type);
            s.owner = this;
            return s;
        }
        else {
            //we shouldn't get here, hopefully.
            throw Error("series type not loaded: " + type);
        }
    }
    createIndicator(typeName) {
        return this.createSeriesComponent("Igx" + typeName + "Component");
    }
    createOverlay(typeName) {
        return this.createSeriesComponent("Igx" + typeName + "Component");
    }
    createSeries(type) {
        switch (type) {
            case DataSeriesType.Area:
                return this.createSeriesComponent('IgxAreaSeriesComponent');
            case DataSeriesType.Column:
                return this.createSeriesComponent('IgxColumnSeriesComponent');
            case DataSeriesType.Line:
                return this.createSeriesComponent('IgxLineSeriesComponent');
            case DataSeriesType.FinancialPrice:
                return this.createSeriesComponent('IgxFinancialPriceSeriesComponent');
            default:
                return this.createSeriesComponent('IgxColumnSeriesComponent');
        }
    }
    createXAxis(type) {
        switch (type) {
            case FinancialChartXAxisMode.Ordinal:
                if (TypeRegistrar.isRegistered("IgxOrdinalTimeXAxisComponent")) {
                    return TypeRegistrar.create("IgxOrdinalTimeXAxisComponent");
                }
                else if (TypeRegistrar.isRegistered("IgxTimeXAxisComponent")) {
                    return TypeRegistrar.create("IgxTimeXAxisComponent");
                }
                else {
                    throw new Error("not valid axes components loaded");
                }
            case FinancialChartXAxisMode.Time:
                if (TypeRegistrar.isRegistered("IgxTimeXAxisComponent")) {
                    return TypeRegistrar.create("IgxTimeXAxisComponent");
                }
                else if (TypeRegistrar.isRegistered("IgxOrdinalTimeXAxisComponent")) {
                    return TypeRegistrar.create("IgxOrdinalTimeXAxisComponent");
                }
                else {
                    throw new Error("not valid axes components loaded");
                }
        }
    }
    createYAxis(type) {
        switch (type) {
            case FinancialChartYAxisMode.Numeric:
                if (TypeRegistrar.isRegistered("IgxNumericYAxisComponent")) {
                    return TypeRegistrar.create("IgxNumericYAxisComponent");
                }
                else if (TypeRegistrar.isRegistered("IgxPercentChangeYAxisComponent")) {
                    return TypeRegistrar.create("IgxPercentChangeYAxisComponent");
                }
                else {
                    throw new Error("not valid axes components loaded");
                }
            case FinancialChartYAxisMode.PercentChange:
                if (TypeRegistrar.isRegistered("IgxPercentChangeYAxisComponent")) {
                    return TypeRegistrar.create("IgxPercentChangeYAxisComponent");
                }
                else if (TypeRegistrar.isRegistered("IgxNumericYAxisComponent")) {
                    return TypeRegistrar.create("IgxNumericYAxisComponent");
                }
                else {
                    throw new Error("not valid axes components loaded");
                }
        }
    }
    set dataSource(value) {
        this._dataSource = value;
        this.bindData();
    }
    get dataSource() {
        return this._dataSource;
    }
    bindData() {
        if (this._chart != null && this._chart !== undefined) {
            this._chart.itemsSource = this._dataSource;
        }
    }
    ngAfterViewInit() {
        if (TypeRegistrar.isRegistered("IgxDataChartDefaultTooltipsComponent")) {
            let c = TypeRegistrar.get("IgxDataChartDefaultTooltipsComponent");
            let cf = this.componentFactoryResolver.resolveComponentFactory(c);
            //let cr = cf.create(this.injector);
            let cr = this._dynamicContent.createComponent(cf);
            this._defaultTooltips = cr;
            cr.instance.onContentReady.subscribe(() => {
                this._onDefaultTooltipsReady(cr);
            });
            this.container.appendChild(cr.location.nativeElement);
        }
        let context = this._chart.getContext();
        let toolbarContext = context.vm.toolbar;
        toolbarContext.vm.financialChartChartTypePicker.template = this.chartTypePickerTemplate ? this.chartTypePickerTemplate : this._defaultTemplates.financialChartChartTypePickerTemplate;
        toolbarContext.vm.financialChartChartTypePicker.vm.notifyChanged = () => { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartIndicatorPicker.template = this.indicatorPickerTemplate ? this.indicatorPickerTemplate : this._defaultTemplates.financialChartIndicatorPickerTemplate;
        toolbarContext.vm.financialChartIndicatorPicker.vm.notifyChanged = () => { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartOverlayPicker.template = this.overlayPickerTemplate ? this.overlayPickerTemplate : this._defaultTemplates.financialChartOverlayPickerTemplate;
        toolbarContext.vm.financialChartOverlayPicker.vm.notifyChanged = () => { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartRangeSelector.template = this.rangeSelectorTemplate ? this.rangeSelectorTemplate : this._defaultTemplates.financialChartRangeSelectorTemplate;
        toolbarContext.vm.financialChartRangeSelector.vm.notifyChanged = () => { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartTrendLineTypePicker.template = this.trendlinePickerTemplate ? this.trendlinePickerTemplate : this._defaultTemplates.financialChartTrendlinePickerTemplate;
        toolbarContext.vm.financialChartTrendLineTypePicker.vm.notifyChanged = () => { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartVolumeTypePicker.template = this.volumeTypePickerTemplate ? this.volumeTypePickerTemplate : this._defaultTemplates.financialChartVolumeTypePickerTemplate;
        toolbarContext.vm.financialChartVolumeTypePicker.vm.notifyChanged = () => { toolbarArea.context = toolbarContext; };
        toolbarContext.template = this.toolbarTemplate ? this.toolbarTemplate : this._defaultTemplates.financialChartToolbarTemplate;
        let toolContainer = toolbarContext.container.rootWrapper.getNativeElement();
        let toolbarArea = this._templates.toArray()[0];
        let mainArea = this._templates.toArray()[1];
        toolbarArea.context = toolbarContext;
        toolbarArea.template = toolbarContext.template;
        let ele = this._toolbarElement.nativeElement;
        ele.style.width = "100%";
        ele.style.height = "100%";
        if (ele.parentElement != null) {
            ele.parentElement.removeChild(ele);
        }
        toolContainer.appendChild(ele);
        this.renderer.setStyle(ele, "display", "");
        let mainContainer = context.container.rootWrapper.getNativeElement();
        let indicatorContainer = context.indicatorsContainer.rootWrapper.getNativeElement();
        let volumeContainer = context.volumeContainer.rootWrapper.getNativeElement();
        let zoomSliderContainer = context.zoomContainer.rootWrapper.getNativeElement();
        var main = mainArea.viewContainer.element.nativeElement;
        let templateMain = main.querySelector(".financialChartPrice");
        let templateToolbar = main.querySelector(".financialChartToolbar");
        let templateIndicator = main.querySelector(".financialChartIndicators");
        let templateVolume = main.querySelector(".financialChartVolume");
        let templateZoomSlider = main.querySelector(".financialChartZoomSlider");
        let grid = main.querySelector(".financialChartMainGrid");
        let gridWrapper = new AngularWrapper(grid, this.renderer, this.ngZone);
        templateMain.appendChild(mainContainer);
        templateToolbar.appendChild(toolContainer);
        templateIndicator.appendChild(indicatorContainer);
        templateVolume.appendChild(volumeContainer);
        templateZoomSlider.appendChild(zoomSliderContainer);
        this._mainElement.nativeElement.parentElement.removeChild(this._mainElement.nativeElement);
        this.container.appendChild(this._mainElement.nativeElement);
        this._chart.provideGrid(gridWrapper);
        this._checkToolbarSize();
    }
    _createZoomSlider(hostEle) {
        if (!TypeRegistrar.isRegistered("IgxZoomSliderComponent")) {
            //shouldn't happen.
            throw new Error("zoom slider component isn't loaded");
        }
        let t = TypeRegistrar.get("IgxZoomSliderComponent");
        let cf = this.componentFactoryResolver.resolveComponentFactory(t);
        let cr = this._dynamicContent.createComponent(cf);
        let ele = cr.location.nativeElement;
        ele.style.width = "100%";
        ele.style.height = "100%";
        cr.instance.width = "100%";
        cr.instance.height = "100%";
        if (ele.parentElement !== null) {
            ele.parentElement.removeChild(ele);
        }
        hostEle.appendChild(ele);
        return cr.instance;
    }
    createTooltip() {
        if (!TypeRegistrar.isRegistered("IgxTooltipContainerComponent")) {
            return null;
        }
        let t = TypeRegistrar.get("IgxTooltipContainerComponent");
        let cf = this.componentFactoryResolver.resolveComponentFactory(t);
        //let cr = cf.create(this.injector);
        let cr = this._dynamicContent.createComponent(cf);
        let ele = cr.location.nativeElement;
        let self = this;
        ele.updateToolTip = function (c) {
            if (c.externalObject) {
                c = c.externalObject;
            }
            else {
                let ext = new DataContext();
                ext._implementation = c;
                c = ext;
            }
            if (ele.parentElement != self.container) {
                if (ele.parentElement != null) {
                    ele.parentElement.removeChild(ele);
                }
                self.container.appendChild(ele);
            }
            cr.instance.context = c;
            ele.style.display = "block";
            return true;
        };
        ele.hideToolTip = function () {
            ele.style.display = "none";
        };
        ele.style.display = "none";
        return cr;
    }
    _ensureTooltipCreated(series) {
        series._ensureTooltipCreated(() => this.createTooltip(), (ele) => {
            let wrapper = new AngularWrapper(ele, this.renderer, this.ngZone);
            wrapper.updateToolTip = ele.updateToolTip;
            wrapper.hideToolTip = ele.hideToolTip;
            return wrapper;
        });
    }
    // private _createXAxis(): any {
    //     let x = new IgxCategoryXAxisComponent();
    //     return x.i;
    // }
    // private _createYAxis(): any {
    //     let y = new IgxNumericYAxisComponent();
    //     return y.i;
    // }
    _ensureDefaultTooltip(series) {
        if (this._defaultTooltips == null) {
            return;
        }
        this._defaultTooltips.instance["ensureDefaultTooltip"](series);
    }
    _onDefaultTooltipsReady(cr) {
        if (this.i.dataChart) {
            var currSeries = this.i.dataChart.series;
            for (var i = 0; i < currSeries.count; i++) {
                if (currSeries.item(i).externalObject.showDefaultTooltip) {
                    this._ensureDefaultTooltip(currSeries.item(i).externalObject);
                }
            }
        }
    }
    get leftMargin() {
        return this.i.bw;
    }
    set leftMargin(v) {
        this.i.bw = +v;
    }
    get isHorizontalZoomEnabled() {
        return this.i.ay;
    }
    set isHorizontalZoomEnabled(v) {
        this.i.ay = ensureBool(v);
    }
    get toolbarHeight() {
        return this.i.qi;
    }
    set toolbarHeight(v) {
        this.i.qi = +v;
    }
    /**
         * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
         * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
        */
    get yAxisIsLogarithmic() {
        return this.i.pw;
    }
    set yAxisIsLogarithmic(v) {
        this.i.pw = ensureBool(v);
    }
    /**
         * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
         * This property is effective only when YAxisIsLogarithmic is true.
        */
    get yAxisLogarithmBase() {
        return this.i.q8;
    }
    set yAxisLogarithmBase(v) {
        this.i.q8 = +v;
    }
    /**
         * Gets or sets the distance between each label and grid line along the Y-axis.
        */
    get yAxisInterval() {
        return this.i.qm;
    }
    set yAxisInterval(v) {
        this.i.qm = +v;
    }
    /**
         * Gets or sets the data value corresponding to the minimum value of the Y-axis.
        */
    get yAxisMinimumValue() {
        return this.i.qo;
    }
    set yAxisMinimumValue(v) {
        this.i.qo = +v;
    }
    /**
         * Gets or sets the data value corresponding to the maximum value of the Y-axis.
        */
    get yAxisMaximumValue() {
        return this.i.qn;
    }
    set yAxisMaximumValue(v) {
        this.i.qn = +v;
    }
    /**
         * Gets or sets the frequency of displayed minor lines along the Y-axis.
        */
    get yAxisMinorInterval() {
        return this.i.qp;
    }
    set yAxisMinorInterval(v) {
        this.i.qp = +v;
    }
    /**
         * Gets the current minimum value for the Y-axis.
        */
    get yAxisActualMinimum() {
        return this.i.ql;
    }
    /**
         * Gets the current maximum value for the Y-axis.
        */
    get yAxisActualMaximum() {
        return this.i.qk;
    }
    /**
         * The type of series to display in the volume pane.
        */
    get volumeType() {
        return this.i.n2;
    }
    set volumeType(v) {
        this.i.n2 = ensureEnum(FinancialChartVolumeType_$type, v);
    }
    /**
         * The scaling mode of the X-axis.
        */
    get xAxisMode() {
        return this.i.n4;
    }
    set xAxisMode(v) {
        this.i.n4 = ensureEnum(FinancialChartXAxisMode_$type, v);
    }
    /**
         * The scaling mode of the Y-axis.
        */
    get yAxisMode() {
        return this.i.n6;
    }
    set yAxisMode(v) {
        this.i.n6 = ensureEnum(FinancialChartYAxisMode_$type, v);
    }
    /**
         * A boolean property controlling the visibility of the toolbar.
        */
    get isToolbarVisible() {
        return this.i.pr;
    }
    set isToolbarVisible(v) {
        this.i.pr = ensureBool(v);
    }
    /**
         * The type of price series to display in the main chart.
        */
    get chartType() {
        return this.i.nx;
    }
    set chartType(v) {
        this.i.nx = ensureEnum(FinancialChartType_$type, v);
    }
    /**
         * Gets or sets Horizontal alignment of Y-axis labels.
        */
    get yAxisLabelHorizontalAlignment() {
        return this.i.lt;
    }
    set yAxisLabelHorizontalAlignment(v) {
        this.i.lt = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * A boolean indicating whether the chart should automatically zoom in vertically on the currently visible range of data.
         * When this property is set to true, panning and zooming along the X-axis will result in a corresponding zoom on the Y-axis, so that the visible range of data fills the zoom window as fully as possible.
        */
    get isWindowSyncedToVisibleRange() {
        return this.i.ps;
    }
    set isWindowSyncedToVisibleRange(v) {
        this.i.ps = ensureBool(v);
    }
    /**
         * A collection indicating what financial indicator types to display on the Financial Chart.
        */
    get indicatorTypes() {
        if (this._indicatorTypes === null) {
            let coll = new FinancialIndicatorTypeCollection();
            let innerColl = this.i.ob;
            let wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new FinancialIndicatorTypeCollection_internal(0);
            }
            this._indicatorTypes = coll._fromInner(innerColl);
            if (wasNull) {
                this.i.ob = innerColl;
            }
        }
        return this._indicatorTypes;
    }
    set indicatorTypes(v) {
        if (this._indicatorTypes !== null) {
            this._indicatorTypes._setSyncTarget(null);
            this._indicatorTypes = null;
        }
        let coll = new FinancialIndicatorTypeCollection();
        this._indicatorTypes = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(FinancialIndicatorType_$type);
        let innerColl = this.i.ob;
        let wasNull = false;
        if (!innerColl) {
            wasNull = true;
            innerColl = new FinancialIndicatorTypeCollection_internal(0);
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._indicatorTypes._setSyncTarget(syncColl);
        if (wasNull) {
            this.i.ob = innerColl;
        }
    }
    /**
         * A collection indicating what financial overlay types to display on the Financial Chart.
        */
    get overlayTypes() {
        if (this._overlayTypes === null) {
            let coll = new FinancialOverlayTypeCollection();
            let innerColl = this.i.od;
            let wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new FinancialOverlayTypeCollection_internal(0);
            }
            this._overlayTypes = coll._fromInner(innerColl);
            if (wasNull) {
                this.i.od = innerColl;
            }
        }
        return this._overlayTypes;
    }
    set overlayTypes(v) {
        if (this._overlayTypes !== null) {
            this._overlayTypes._setSyncTarget(null);
            this._overlayTypes = null;
        }
        let coll = new FinancialOverlayTypeCollection();
        this._overlayTypes = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(FinancialOverlayType_$type);
        let innerColl = this.i.od;
        let wasNull = false;
        if (!innerColl) {
            wasNull = true;
            innerColl = new FinancialOverlayTypeCollection_internal(0);
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._overlayTypes._setSyncTarget(syncColl);
        if (wasNull) {
            this.i.od = innerColl;
        }
    }
    /**
         * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
        */
    get yAxisAbbreviateLargeNumbers() {
        return this.i.pv;
    }
    set yAxisAbbreviateLargeNumbers(v) {
        this.i.pv = ensureBool(v);
    }
    /**
         * Gets or sets the rendering resolution for all series in this chart.
         * Where n = Resolution, for every n horizontal pixels, combine all items into a single datapoint.  When Resolution = 0, all datapoints will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
        */
    get resolution() {
        return this.i.by;
    }
    set resolution(v) {
        this.i.by = +v;
    }
    /**
         * The location of Y-axis labels, relative to the plot area.
        */
    get yAxisLabelLocation() {
        return this.i.gq;
    }
    set yAxisLabelLocation(v) {
        this.i.gq = ensureEnum(AxisLabelsLocation_$type, v);
    }
    /**
         * The type of series to display in the zoom slider pane.
        */
    get zoomSliderType() {
        return this.i.n9;
    }
    set zoomSliderType(v) {
        this.i.n9 = ensureEnum(FinancialChartZoomSliderType_$type, v);
    }
    /**
         * Gets or sets the palette used for coloring negative items of Waterfall chart type.
        */
    get negativeBrushes() {
        return fromBrushCollection(this.i.m6);
    }
    set negativeBrushes(v) {
        this.i.m6 = toBrushCollection(v);
    }
    /**
         * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
        */
    get negativeOutlines() {
        return fromBrushCollection(this.i.m7);
    }
    set negativeOutlines(v) {
        this.i.m7 = toBrushCollection(v);
    }
    /**
         * Brushes to use for filling financial overlays.
        */
    get overlayBrushes() {
        return fromBrushCollection(this.i.m8);
    }
    set overlayBrushes(v) {
        this.i.m8 = toBrushCollection(v);
    }
    /**
         * Brushes to use for outlining financial overlays.
        */
    get overlayOutlines() {
        return fromBrushCollection(this.i.m9);
    }
    set overlayOutlines(v) {
        this.i.m9 = toBrushCollection(v);
    }
    /**
         * Brushes to use for outlining volume series in the volume pane.
        */
    get volumeOutlines() {
        return fromBrushCollection(this.i.nb);
    }
    set volumeOutlines(v) {
        this.i.nb = toBrushCollection(v);
    }
    /**
         * Brushes to use for filling volume series in the volume pane.
        */
    get volumeBrushes() {
        return fromBrushCollection(this.i.na);
    }
    set volumeBrushes(v) {
        this.i.na = toBrushCollection(v);
    }
    /**
         * Brushes to use for negative elements in financial indicators.
        */
    get indicatorNegativeBrushes() {
        return fromBrushCollection(this.i.m5);
    }
    set indicatorNegativeBrushes(v) {
        this.i.m5 = toBrushCollection(v);
    }
    /**
         * Brushes to use for financial indicators.
        */
    get indicatorBrushes() {
        return fromBrushCollection(this.i.m4);
    }
    set indicatorBrushes(v) {
        this.i.m4 = toBrushCollection(v);
    }
    /**
         * The outline thickness of volume series in the volume pane.
        */
    get volumeThickness() {
        return this.i.qj;
    }
    set volumeThickness(v) {
        this.i.qj = +v;
    }
    /**
         * The outline thickness of financial overlays.
        */
    get overlayThickness() {
        return this.i.qh;
    }
    set overlayThickness(v) {
        this.i.qh = +v;
    }
    /**
         * The outline or stroke thickness of financial indicators.
        */
    get indicatorThickness() {
        return this.i.qg;
    }
    set indicatorThickness(v) {
        this.i.qg = +v;
    }
    /**
         * The display types of financial indicators.
        */
    get indicatorDisplayTypes() {
        if (this._indicatorDisplayTypes === null) {
            let coll = new IndicatorDisplayTypeCollection();
            let innerColl = this.i.ol;
            let wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new IndicatorDisplayTypeCollection_internal();
            }
            this._indicatorDisplayTypes = coll._fromInner(innerColl);
            if (wasNull) {
                this.i.ol = innerColl;
            }
        }
        return this._indicatorDisplayTypes;
    }
    set indicatorDisplayTypes(v) {
        if (this._indicatorDisplayTypes !== null) {
            this._indicatorDisplayTypes._setSyncTarget(null);
            this._indicatorDisplayTypes = null;
        }
        let coll = new IndicatorDisplayTypeCollection();
        this._indicatorDisplayTypes = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(IndicatorDisplayType_$type);
        let innerColl = this.i.ol;
        let wasNull = false;
        if (!innerColl) {
            wasNull = true;
            innerColl = new IndicatorDisplayTypeCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._indicatorDisplayTypes._setSyncTarget(syncColl);
        if (wasNull) {
            this.i.ol = innerColl;
        }
    }
    /**
         * The period of financial indicators, where applicable.
        */
    get indicatorPeriod() {
        return this.i.q3;
    }
    set indicatorPeriod(v) {
        this.i.q3 = +v;
    }
    /**
         * The multiplier of financial indicators, where applicable.
        */
    get indicatorMultiplier() {
        return this.i.qf;
    }
    set indicatorMultiplier(v) {
        this.i.qf = +v;
    }
    /**
         * The smoothing period of financial indicators, where applicable.
        */
    get indicatorSmoothingPeriod() {
        return this.i.q6;
    }
    set indicatorSmoothingPeriod(v) {
        this.i.q6 = +v;
    }
    /**
         * The short period of financial indicators, where applicable.
        */
    get indicatorShortPeriod() {
        return this.i.q4;
    }
    set indicatorShortPeriod(v) {
        this.i.q4 = +v;
    }
    /**
         * The long period of financial indicators, where applicable.
        */
    get indicatorLongPeriod() {
        return this.i.q2;
    }
    set indicatorLongPeriod(v) {
        this.i.q2 = +v;
    }
    /**
         * The signal period of financial indicators, where applicable.
        */
    get indicatorSignalPeriod() {
        return this.i.q5;
    }
    set indicatorSignalPeriod(v) {
        this.i.q5 = +v;
    }
    /**
         * A FinancialChartRangeSelectorOptionCollection containing the available range selector options on the toolbar.
        */
    get rangeSelectorOptions() {
        if (this._rangeSelectorOptions === null) {
            let coll = new FinancialChartRangeSelectorOptionCollection();
            let innerColl = this.i.nt;
            let wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new FinancialChartRangeSelectorOptionCollection_internal(0);
            }
            this._rangeSelectorOptions = coll._fromInner(innerColl);
            if (wasNull) {
                this.i.nt = innerColl;
            }
        }
        return this._rangeSelectorOptions;
    }
    set rangeSelectorOptions(v) {
        if (this._rangeSelectorOptions !== null) {
            this._rangeSelectorOptions._setSyncTarget(null);
            this._rangeSelectorOptions = null;
        }
        let coll = new FinancialChartRangeSelectorOptionCollection();
        this._rangeSelectorOptions = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(FinancialChartRangeSelectorOption_$type);
        let innerColl = this.i.nt;
        let wasNull = false;
        if (!innerColl) {
            wasNull = true;
            innerColl = new FinancialChartRangeSelectorOptionCollection_internal(0);
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._rangeSelectorOptions._setSyncTarget(syncColl);
        if (wasNull) {
            this.i.nt = innerColl;
        }
    }
    /**
         * The names of custom indicators to add to the chart.
         * When CustomIndicatorNames is set, the ApplyCustomIndicators event will be raised for each custom indicator name.
        */
    get customIndicatorNames() {
        if (this._customIndicatorNames === null) {
            let coll = new CustomIndicatorNameCollection();
            let innerColl = this.i.customIndicatorNames;
            let wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new CustomIndicatorNameCollection_internal(0);
            }
            this._customIndicatorNames = coll._fromInner(innerColl);
            if (wasNull) {
                this.i.customIndicatorNames = innerColl;
            }
        }
        return this._customIndicatorNames;
    }
    set customIndicatorNames(v) {
        if (this._customIndicatorNames !== null) {
            this._customIndicatorNames._setSyncTarget(null);
            this._customIndicatorNames = null;
        }
        let coll = new CustomIndicatorNameCollection();
        this._customIndicatorNames = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(String_$type);
        let innerColl = this.i.customIndicatorNames;
        let wasNull = false;
        if (!innerColl) {
            wasNull = true;
            innerColl = new CustomIndicatorNameCollection_internal(0);
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._customIndicatorNames._setSyncTarget(syncColl);
        if (wasNull) {
            this.i.customIndicatorNames = innerColl;
        }
    }
    get isVerticalZoomEnabled() {
        return this.i.a3;
    }
    set isVerticalZoomEnabled(v) {
        this.i.a3 = ensureBool(v);
    }
    provideContainer(container) {
        this.i.provideContainer(container);
    }
    notifyInsertItem(source_, index, newItem) {
        this.i.e9(source_, index, newItem);
    }
    notifyRemoveItem(source_, index, oldItem) {
        this.i.fa(source_, index, oldItem);
    }
    notifyClearItems(source_) {
        this.i.e8(source_);
    }
    notifySetItem(source_, index, oldItem, newItem) {
        this.i.fc(source_, index, oldItem, newItem);
    }
    /**
         * Returns visuals as a serialized string.
        
        */
    exportSerializedVisualData() {
        let iv = this.i.rs();
        return (iv);
    }
    /**
         * Event raised by the chart when custom indicator data is needed from the application.
         * During series rendering, event will be raised once for each value in the CustomIndicatorNames collection.
        */
    get applyCustomIndicators() {
        if (this._applyCustomIndicators == null) {
            this._applyCustomIndicators = new EventEmitter();
            this.i.applyCustomIndicators = delegateCombine(this.i.applyCustomIndicators, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new FinancialChartCustomIndicatorArgs();
                    outerArgs._provideImplementation(e);
                    this._applyCustomIndicators.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._applyCustomIndicators;
    }
}
IgxFinancialChartComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-financial-chart',
                template: `
    <ng-template #financialChartTemplate>
        <div class='financialChartMainGrid'>
		    <div class='financialChartToolbar'></div>
		    <div class='financialChartPrice'></div>
		    <div class='financialChartIndicators'></div>
		    <div class='financialChartVolume'></div>
		    <div class='financialChartZoomSlider'></div>
	    </div>
    </ng-template>

    <ng-container #dynamicContent></ng-container>
    <igx-financial-chart-default-templates #defaultTemplates></igx-financial-chart-default-templates>
    <igx-template-content #toolbarContent style="display: none"></igx-template-content>
	<igx-template-content
		style="width: 100%; height: 100%"
		#mainContent [template]="chartTemplate ? chartTemplate : financialChartTemplate"></igx-template-content>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: IgxFinancialChartComponent_PROVIDERS,
                styles: [`
		:host {
			display: block;
		}
        .financialChartToolbar {
            grid-row: 1;
            -ms-grid-row: 1;
        }
        .financialChartPrice {
            grid-row: 2;
            -ms-grid-row: 2;
        }
        .financialChartIndicators {
            grid-row: 3;
            -ms-grid-row: 3;
        }
        .financialChartVolume {
            grid-row: 4;
            -ms-grid-row: 4;
        }
        .financialChartZoomSlider {
            grid-row: 5;
            -ms-grid-row: 5;
        }
		.financialChartMainGrid {
			height: 100%;
			width: 100%;
			display: grid;
			display: -ms-grid;
			-ms-grid-columns: 100%;
		}
	`],
                host: {
                    '(document:click)': 'onDocumentClick($event)'
                }
            },] },
];
/** @nocollapse */
IgxFinancialChartComponent.ctorParameters = () => [
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
    { type: NgZone, },
    { type: Injector, },
    { type: ComponentFactoryResolver, },
];
IgxFinancialChartComponent.propDecorators = {
    "_dynamicContent": [{ type: ViewChild, args: ["dynamicContent", { read: ViewContainerRef },] },],
    "_defaultTemplates": [{ type: ViewChild, args: [IgxFinancialChartDefaultTemplatesComponent,] },],
    "_templates": [{ type: ViewChildren, args: [IgxTemplateContentComponent,] },],
    "_toolbarElement": [{ type: ViewChild, args: ['toolbarContent', { read: ElementRef },] },],
    "_mainElement": [{ type: ViewChild, args: ['mainContent', { read: ElementRef },] },],
    "height": [{ type: Input },],
    "width": [{ type: Input },],
    "rangeSelectorTemplate": [{ type: Input },],
    "trendlinePickerTemplate": [{ type: Input },],
    "overlayPickerTemplate": [{ type: Input },],
    "chartTypePickerTemplate": [{ type: Input },],
    "volumeTypePickerTemplate": [{ type: Input },],
    "indicatorPickerTemplate": [{ type: Input },],
    "toolbarTemplate": [{ type: Input },],
    "chartTemplate": [{ type: Input },],
    "dataSource": [{ type: Input },],
    "leftMargin": [{ type: Input },],
    "isHorizontalZoomEnabled": [{ type: Input },],
    "toolbarHeight": [{ type: Input },],
    "yAxisIsLogarithmic": [{ type: Input },],
    "yAxisLogarithmBase": [{ type: Input },],
    "yAxisInterval": [{ type: Input },],
    "yAxisMinimumValue": [{ type: Input },],
    "yAxisMaximumValue": [{ type: Input },],
    "yAxisMinorInterval": [{ type: Input },],
    "volumeType": [{ type: Input },],
    "xAxisMode": [{ type: Input },],
    "yAxisMode": [{ type: Input },],
    "isToolbarVisible": [{ type: Input },],
    "chartType": [{ type: Input },],
    "yAxisLabelHorizontalAlignment": [{ type: Input },],
    "isWindowSyncedToVisibleRange": [{ type: Input },],
    "indicatorTypes": [{ type: Input },],
    "overlayTypes": [{ type: Input },],
    "yAxisAbbreviateLargeNumbers": [{ type: Input },],
    "resolution": [{ type: Input },],
    "yAxisLabelLocation": [{ type: Input },],
    "zoomSliderType": [{ type: Input },],
    "negativeBrushes": [{ type: Input },],
    "negativeOutlines": [{ type: Input },],
    "overlayBrushes": [{ type: Input },],
    "overlayOutlines": [{ type: Input },],
    "volumeOutlines": [{ type: Input },],
    "volumeBrushes": [{ type: Input },],
    "indicatorNegativeBrushes": [{ type: Input },],
    "indicatorBrushes": [{ type: Input },],
    "volumeThickness": [{ type: Input },],
    "overlayThickness": [{ type: Input },],
    "indicatorThickness": [{ type: Input },],
    "indicatorDisplayTypes": [{ type: Input },],
    "indicatorPeriod": [{ type: Input },],
    "indicatorMultiplier": [{ type: Input },],
    "indicatorSmoothingPeriod": [{ type: Input },],
    "indicatorShortPeriod": [{ type: Input },],
    "indicatorLongPeriod": [{ type: Input },],
    "indicatorSignalPeriod": [{ type: Input },],
    "rangeSelectorOptions": [{ type: Input },],
    "customIndicatorNames": [{ type: Input },],
    "isVerticalZoomEnabled": [{ type: Input },],
    "applyCustomIndicators": [{ type: Output },],
};
//# sourceMappingURL=igx-financial-chart-component.js.map