import { Type } from '@angular/core';
import { IgxDataTemplate } from './IgxDataTemplate';
import { MarkerType } from './MarkerType';
import { IgxSeriesComponent } from './igx-series-component';
import { MarkerSeries } from "./MarkerSeries";
/**
 * Represents the base class for series containing markers.
*/
export declare const IgxMarkerSeriesComponent_PROVIDERS: {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
}[];
export declare abstract class IgxMarkerSeriesComponent extends IgxSeriesComponent {
    readonly i: MarkerSeries;
    constructor();
    /**
     * Returns whether the current series supports visual markers.
    */
    readonly hasMarkers: boolean;
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    markerType: MarkerType;
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    markerTemplate: IgxDataTemplate;
    /**
     * Gets the effective marker template for the current series object.
    */
    readonly actualMarkerTemplate: IgxDataTemplate;
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    markerBrush: string;
    /**
     * Gets the effective marker brush for the current series object.
    */
    readonly actualMarkerBrush: string;
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    markerOutline: string;
    /**
     * Gets the effective marker outline for the current series object.
    */
    readonly actualMarkerOutline: string;
}
