import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from './igx-strategy-based-indicator-component';
import { IgxFinancialIndicatorComponent } from './igx-financial-indicator-component';
import { IgxFinancialSeriesComponent } from './igx-financial-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { MovingAverageConvergenceDivergenceIndicator } from "./MovingAverageConvergenceDivergenceIndicator";
/**
 * Represents a IgxDataChartComponent Moving Average Convergence/Divergence (MACD) indicator series.
 * Default required members: High, Low, Close
*/
export const IgxMovingAverageConvergenceDivergenceIndicatorComponent_PROVIDERS = [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(() => IgxMovingAverageConvergenceDivergenceIndicatorComponent) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(() => IgxMovingAverageConvergenceDivergenceIndicatorComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxMovingAverageConvergenceDivergenceIndicatorComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxMovingAverageConvergenceDivergenceIndicatorComponent) }];
export class IgxMovingAverageConvergenceDivergenceIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new MovingAverageConvergenceDivergenceIndicator();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the short moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
         * The typical, and initial, value for short MACD periods is 10.
        */
    get shortPeriod() {
        return this.i.shortPeriod;
    }
    set shortPeriod(v) {
        this.i.shortPeriod = +v;
    }
    /**
         * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
         * The typical, and initial, value for long MACD periods is 30.
        */
    get longPeriod() {
        return this.i.longPeriod;
    }
    set longPeriod(v) {
        this.i.longPeriod = +v;
    }
    /**
         * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
         * The typical, and initial, value for long PVO periods is 30.
        */
    get signalPeriod() {
        return this.i.signalPeriod;
    }
    set signalPeriod(v) {
        this.i.signalPeriod = +v;
    }
}
IgxMovingAverageConvergenceDivergenceIndicatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-moving-average-convergence-divergence-indicator',
                template: ``,
                providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(() => IgxMovingAverageConvergenceDivergenceIndicatorComponent) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(() => IgxMovingAverageConvergenceDivergenceIndicatorComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxMovingAverageConvergenceDivergenceIndicatorComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxMovingAverageConvergenceDivergenceIndicatorComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxMovingAverageConvergenceDivergenceIndicatorComponent.ctorParameters = () => [];
IgxMovingAverageConvergenceDivergenceIndicatorComponent.propDecorators = {
    "shortPeriod": [{ type: Input },],
    "longPeriod": [{ type: Input },],
    "signalPeriod": [{ type: Input },],
};
//# sourceMappingURL=igx-moving-average-convergence-divergence-indicator-component.js.map