import { forwardRef, Input } from '@angular/core';
import { IgxAxisComponent } from './igx-axis-component';
import { ensureBool } from "./componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent numeric axes.
*/
export const IgxNumericAxisBaseComponent_PROVIDERS = [{ provide: IgxAxisComponent, useExisting: forwardRef(() => IgxNumericAxisBaseComponent) }];
export class IgxNumericAxisBaseComponent extends IgxAxisComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets if the current axis is of numeric axis type
        */
    get isNumeric() {
        return this.i.b1;
    }
    /**
         * Gets or sets the MinimumValue property.
        */
    get minimumValue() {
        return this.i.jo;
    }
    set minimumValue(v) {
        this.i.jo = +v;
    }
    /**
         * Gets the effective minimum value for the current numeric axis object.
        */
    get actualMinimumValue() {
        return this.i.jg;
    }
    /**
         * Gets the effective minimum value for the current numeric axis object.
        */
    get actualVisibleMinimumValue() {
        return this.i.jj;
    }
    /**
         * Gets or sets the MaximumValue property.
        */
    get maximumValue() {
        return this.i.jn;
    }
    set maximumValue(v) {
        this.i.jn = +v;
    }
    /**
         * Gets the effective maximum value for the current numeric axis object.
        */
    get actualMaximumValue() {
        return this.i.jf;
    }
    /**
         * Gets the effective visible maximum value for the current numeric axis object.
        */
    get actualVisibleMaximumValue() {
        return this.i.ji;
    }
    /**
         * Gets or sets the Interval property.
        */
    get interval() {
        return this.i.jk;
    }
    set interval(v) {
        this.i.jk = +v;
    }
    /**
         * Gets the effective value for the current Interval.
        */
    get actualInterval() {
        return this.i.je;
    }
    /**
         * Gets or sets the MinorInterval property.
        */
    get minorInterval() {
        return this.i.jp;
    }
    set minorInterval(v) {
        this.i.jp = +v;
    }
    /**
         * Gets the effective value for the current MinorInterval.
        */
    get actualMinorInterval() {
        return this.i.jh;
    }
    /**
         * Gets or sets the ReferenceValue property.
        */
    get referenceValue() {
        return this.i.jq;
    }
    set referenceValue(v) {
        this.i.jq = +v;
    }
    /**
         * Gets or sets the IsLogarithmic property.
        */
    get isLogarithmic() {
        return this.i.i5;
    }
    set isLogarithmic(v) {
        this.i.i5 = ensureBool(v);
    }
    /**
         * Determines if the axis has a valid logarithmic scale.
        */
    get actualIsLogarithmic() {
        return this.i.i1;
    }
    /**
         * Gets or sets the LogarithmBase property.
        */
    get logarithmBase() {
        return this.i.js;
    }
    set logarithmBase(v) {
        this.i.js = +v;
    }
    /**
         * Determines if the axis has a user-defined minimum.
        */
    get hasUserMinimum() {
        return this.i.i4;
    }
    /**
         * Determines if the axis has a user-defined maximum.
        */
    get hasUserMaximum() {
        return this.i.i3;
    }
    get abbreviateLargeNumbers() {
        return this.i.i0;
    }
    set abbreviateLargeNumbers(v) {
        this.i.i0 = ensureBool(v);
    }
    /**
         * Unscales a value from screen space into axis space.
        
        * @param unscaledValue  * The scaled value in screen coordinates to unscale into axis space.
        */
    unscaleValue(unscaledValue) {
        let iv = this.i.jr(unscaledValue);
        return (iv);
    }
}
IgxNumericAxisBaseComponent.propDecorators = {
    "minimumValue": [{ type: Input },],
    "maximumValue": [{ type: Input },],
    "interval": [{ type: Input },],
    "minorInterval": [{ type: Input },],
    "referenceValue": [{ type: Input },],
    "isLogarithmic": [{ type: Input },],
    "logarithmBase": [{ type: Input },],
    "abbreviateLargeNumbers": [{ type: Input },],
};
//# sourceMappingURL=igx-numeric-axis-base-component.js.map