import { Type, EventEmitter } from '@angular/core';
import { TimeAxisLabelFormatCollection } from './igx-time-axis-label-format-collection';
import { AxisRangeChangedEventArgs } from './igx-axis-range-changed-event-args';
import { IgxCategoryXAxisComponent } from './igx-category-x-axis-component';
import { IgxAxisComponent } from './igx-axis-component';
import { OrdinalTimeXAxis } from "./OrdinalTimeXAxis";
/**
 * A horizontal axis that uses an ordinal DateTime scale.
 * On an ordinal time axis, datapoints are aligned according to their order in the ItemsSource, like a category axis.
*
* You can use the `OrdinalTimeXAxis` to display dates at equidistant.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-ordinal-time-x-axis
* 		dateTimeMemberPath="date"
* 		#xAxis>
*     </igx-ordinal-time-x-axis>
* </igx-data-chart>
* ```
*/
export declare const IgxOrdinalTimeXAxisComponent_PROVIDERS: {
    provide: typeof IgxAxisComponent;
    useExisting: Type<any>;
}[];
export declare class IgxOrdinalTimeXAxisComponent extends IgxCategoryXAxisComponent {
    protected createImplementation(): OrdinalTimeXAxis;
    readonly i: OrdinalTimeXAxis;
    constructor();
    dateTimeMemberPath: string;
    private _labelFormats;
    /**
     * A list of axis label formats to apply, which are selected according to the visible axis range.
     * The label format selected will be the one with the largest range smaller than the visible range of the axis.
    *
    * You can use the `LabelFormats` for adjusting the labels depending on the range of the time shown by the chart.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-ordinal-time-x-axis
    * 		[labelFormats]="labelFormats"
    * 		dateTimeMemberPath="time"
    * 		#xAxis>
    *     </igx-ordinal-time-x-axis>
    * </igx-data-chart>
    * ```
    */
    labelFormats: TimeAxisLabelFormatCollection;
    private _actualRangeChanged;
    readonly actualRangeChanged: EventEmitter<{
        sender: any;
        args: AxisRangeChangedEventArgs;
    }>;
}
