import { forwardRef, Input } from '@angular/core';
import { HorizontalAlignment, HorizontalAlignment_$type } from './HorizontalAlignment';
import { VerticalAlignment, VerticalAlignment_$type } from './VerticalAlignment';
import { Visibility, Visibility_$type } from './Visibility';
import { AxisLabelsLocation, AxisLabelsLocation_$type } from './AxisLabelsLocation';
import { IgxDomainChartComponent } from './igx-domain-chart-component';
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "./componentUtil";
/**
 * Represents a base class for domain charts with X/Y axes
*/
export const IgxXYChartComponent_PROVIDERS = [{ provide: IgxDomainChartComponent, useExisting: forwardRef(() => IgxXYChartComponent) }];
export class IgxXYChartComponent extends IgxDomainChartComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets function which takes an context object and returns a formatted label for the X-axis.
        */
    get xAxisFormatLabel() {
        return this.i.gn;
    }
    set xAxisFormatLabel(v) {
        this.i.gn = v;
    }
    /**
         * Gets or sets function which takes a context object and returns a formatted label for the Y-axis.
        */
    get yAxisFormatLabel() {
        return this.i.go;
    }
    set yAxisFormatLabel(v) {
        this.i.go = v;
    }
    /**
         * Gets or sets the left margin of labels on the X-axis
        */
    get xAxisLabelLeftMargin() {
        return this.i.h0;
    }
    set xAxisLabelLeftMargin(v) {
        this.i.h0 = +v;
    }
    /**
         * Gets or sets the top margin of labels on the X-axis
        */
    get xAxisLabelTopMargin() {
        return this.i.h2;
    }
    set xAxisLabelTopMargin(v) {
        this.i.h2 = +v;
    }
    /**
         * Gets or sets the right margin of labels on the X-axis
        */
    get xAxisLabelRightMargin() {
        return this.i.h1;
    }
    set xAxisLabelRightMargin(v) {
        this.i.h1 = +v;
    }
    /**
         * Gets or sets the bottom margin of labels on the X-axis
        */
    get xAxisLabelBottomMargin() {
        return this.i.hz;
    }
    set xAxisLabelBottomMargin(v) {
        this.i.hz = +v;
    }
    /**
         * Gets or sets the left margin of labels on the Y-axis
        */
    get yAxisLabelLeftMargin() {
        return this.i.ii;
    }
    set yAxisLabelLeftMargin(v) {
        this.i.ii = +v;
    }
    /**
         * Gets or sets the top margin of labels on the Y-axis
        */
    get yAxisLabelTopMargin() {
        return this.i.ik;
    }
    set yAxisLabelTopMargin(v) {
        this.i.ik = +v;
    }
    /**
         * Gets or sets the right margin of labels on the Y-axis
        */
    get yAxisLabelRightMargin() {
        return this.i.ij;
    }
    set yAxisLabelRightMargin(v) {
        this.i.ij = +v;
    }
    /**
         * Gets or sets the bottom margin of labels on the Y-axis
        */
    get yAxisLabelBottomMargin() {
        return this.i.ih;
    }
    set yAxisLabelBottomMargin(v) {
        this.i.ih = +v;
    }
    /**
         * Gets or sets color of labels on the X-axis
        */
    get xAxisLabelTextColor() {
        return brushToString(this.i.l8);
    }
    set xAxisLabelTextColor(v) {
        this.i.l8 = stringToBrush(v);
    }
    /**
         * Gets or sets color of labels on the Y-axis
        */
    get yAxisLabelTextColor() {
        return brushToString(this.i.mf);
    }
    set yAxisLabelTextColor(v) {
        this.i.mf = stringToBrush(v);
    }
    /**
         * Gets or sets the margin around a title on the X-axis
        */
    get xAxisTitleMargin() {
        return this.i.ib;
    }
    set xAxisTitleMargin(v) {
        this.i.ib = +v;
    }
    /**
         * Gets or sets the margin around a title on the Y-axis
        */
    get yAxisTitleMargin() {
        return this.i.iu;
    }
    set yAxisTitleMargin(v) {
        this.i.iu = +v;
    }
    /**
         * Gets or sets the left margin of a title on the X-axis
        */
    get xAxisTitleLeftMargin() {
        return this.i.ia;
    }
    set xAxisTitleLeftMargin(v) {
        this.i.ia = +v;
    }
    /**
         * Gets or sets the left margin of a title on the Y-axis
        */
    get yAxisTitleLeftMargin() {
        return this.i.it;
    }
    set yAxisTitleLeftMargin(v) {
        this.i.it = +v;
    }
    /**
         * Gets or sets the top margin of a title on the X-axis
        */
    get xAxisTitleTopMargin() {
        return this.i.id;
    }
    set xAxisTitleTopMargin(v) {
        this.i.id = +v;
    }
    /**
         * Gets or sets the top margin of a title on the Y-axis
        */
    get yAxisTitleTopMargin() {
        return this.i.iw;
    }
    set yAxisTitleTopMargin(v) {
        this.i.iw = +v;
    }
    /**
         * Gets or sets the right margin of a title on the X-axis
        */
    get xAxisTitleRightMargin() {
        return this.i.ic;
    }
    set xAxisTitleRightMargin(v) {
        this.i.ic = +v;
    }
    /**
         * Gets or sets the right margin of a title on the Y-axis
        */
    get yAxisTitleRightMargin() {
        return this.i.iv;
    }
    set yAxisTitleRightMargin(v) {
        this.i.iv = +v;
    }
    /**
         * Gets or sets the bottom margin of a title on the X-axis
        */
    get xAxisTitleBottomMargin() {
        return this.i.h9;
    }
    set xAxisTitleBottomMargin(v) {
        this.i.h9 = +v;
    }
    /**
         * Gets or sets the bottom margin of a title on the Y-axis
        */
    get yAxisTitleBottomMargin() {
        return this.i.is;
    }
    set yAxisTitleBottomMargin(v) {
        this.i.is = +v;
    }
    /**
         * Gets or sets color of title on the X-axis
        */
    get xAxisTitleTextColor() {
        return brushToString(this.i.me);
    }
    set xAxisTitleTextColor(v) {
        this.i.me = stringToBrush(v);
    }
    /**
         * Gets or sets color of title on the Y-axis
        */
    get yAxisTitleTextColor() {
        return brushToString(this.i.ml);
    }
    set yAxisTitleTextColor(v) {
        this.i.ml = stringToBrush(v);
    }
    /**
         * Gets or sets CSS font property for labels on X-axis
        */
    get xAxisLabelTextStyle() {
        return this.i.ji;
    }
    set xAxisLabelTextStyle(v) {
        this.i.ji = v;
    }
    /**
         * Gets or sets CSS font property for labels on Y-axis
        */
    get yAxisLabelTextStyle() {
        return this.i.kk;
    }
    set yAxisLabelTextStyle(v) {
        this.i.kk = v;
    }
    /**
         * Gets or sets CSS font property for title on X-axis
        */
    get xAxisTitleTextStyle() {
        return this.i.j6;
    }
    set xAxisTitleTextStyle(v) {
        this.i.j6 = v;
    }
    /**
         * Gets or sets CSS font property for title on Y-axis
        */
    get yAxisTitleTextStyle() {
        return this.i.k8;
    }
    set yAxisTitleTextStyle(v) {
        this.i.k8 = v;
    }
    /**
         * Gets or sets the format for labels along the X-axis.
        */
    get xAxisLabel() {
        return this.i.iz;
    }
    set xAxisLabel(v) {
        this.i.iz = v;
    }
    /**
         * Gets or sets the format for labels along the Y-axis.
        */
    get yAxisLabel() {
        return this.i.i0;
    }
    set yAxisLabel(v) {
        this.i.i0 = v;
    }
    /**
         * Gets or sets the color to apply to major gridlines along the X-axis.
        */
    get xAxisMajorStroke() {
        return brushToString(this.i.l9);
    }
    set xAxisMajorStroke(v) {
        this.i.l9 = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to major gridlines along the Y-axis.
        */
    get yAxisMajorStroke() {
        return brushToString(this.i.mg);
    }
    set yAxisMajorStroke(v) {
        this.i.mg = stringToBrush(v);
    }
    /**
         * Gets or sets the thickness to apply to major gridlines along the X-axis.
        */
    get xAxisMajorStrokeThickness() {
        return this.i.h3;
    }
    set xAxisMajorStrokeThickness(v) {
        this.i.h3 = +v;
    }
    /**
         * Gets or sets the thickness to apply to major gridlines along the Y-axis.
        */
    get yAxisMajorStrokeThickness() {
        return this.i.il;
    }
    set yAxisMajorStrokeThickness(v) {
        this.i.il = +v;
    }
    /**
         * Gets or sets the thickness to apply to minor gridlines along the X-axis.
        */
    get xAxisMinorStrokeThickness() {
        return this.i.h4;
    }
    set xAxisMinorStrokeThickness(v) {
        this.i.h4 = +v;
    }
    /**
         * Gets or sets the thickness to apply to minor gridlines along the Y-axis.
        */
    get yAxisMinorStrokeThickness() {
        return this.i.im;
    }
    set yAxisMinorStrokeThickness(v) {
        this.i.im = +v;
    }
    /**
         * Gets or sets the color to apply to stripes along the X-axis.
        */
    get xAxisStrip() {
        return brushToString(this.i.mb);
    }
    set xAxisStrip(v) {
        this.i.mb = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to stripes along the Y-axis.
        */
    get yAxisStrip() {
        return brushToString(this.i.mi);
    }
    set yAxisStrip(v) {
        this.i.mi = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to the X-axis line.
        */
    get xAxisStroke() {
        return brushToString(this.i.mc);
    }
    set xAxisStroke(v) {
        this.i.mc = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to the Y-axis line.
        */
    get yAxisStroke() {
        return brushToString(this.i.mj);
    }
    set yAxisStroke(v) {
        this.i.mj = stringToBrush(v);
    }
    /**
         * Gets or sets the thickness to apply to the X-axis line.
        */
    get xAxisStrokeThickness() {
        return this.i.h5;
    }
    set xAxisStrokeThickness(v) {
        this.i.h5 = +v;
    }
    /**
         * Gets or sets the thickness to apply to the Y-axis line.
        */
    get yAxisStrokeThickness() {
        return this.i.io;
    }
    set yAxisStrokeThickness(v) {
        this.i.io = +v;
    }
    /**
         * Gets or sets the length of tickmarks along the X-axis.
        */
    get xAxisTickLength() {
        return this.i.h6;
    }
    set xAxisTickLength(v) {
        this.i.h6 = +v;
    }
    /**
         * Gets or sets the length of tickmarks along the Y-axis.
        */
    get yAxisTickLength() {
        return this.i.ip;
    }
    set yAxisTickLength(v) {
        this.i.ip = +v;
    }
    /**
         * Gets or sets the color to apply to tickmarks along the X-axis.
        */
    get xAxisTickStroke() {
        return brushToString(this.i.md);
    }
    set xAxisTickStroke(v) {
        this.i.md = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to tickmarks along the Y-axis.
        */
    get yAxisTickStroke() {
        return brushToString(this.i.mk);
    }
    set yAxisTickStroke(v) {
        this.i.mk = stringToBrush(v);
    }
    /**
         * Gets or sets the thickness to apply to tickmarks along the X-axis.
        */
    get xAxisTickStrokeThickness() {
        return this.i.h7;
    }
    set xAxisTickStrokeThickness(v) {
        this.i.h7 = +v;
    }
    /**
         * Gets or sets the thickness to apply to tickmarks along the Y-axis.
        */
    get yAxisTickStrokeThickness() {
        return this.i.iq;
    }
    set yAxisTickStrokeThickness(v) {
        this.i.iq = +v;
    }
    /**
         * Gets or sets the Text to display below the X-axis.
        */
    get xAxisTitle() {
        return this.i.jx;
    }
    set xAxisTitle(v) {
        this.i.jx = v;
    }
    /**
         * Gets or sets the Text to display to the left of the Y-axis.
        */
    get yAxisTitle() {
        return this.i.kz;
    }
    set yAxisTitle(v) {
        this.i.kz = v;
    }
    /**
         * Gets or sets the color to apply to minor gridlines along the X-axis.
        */
    get xAxisMinorStroke() {
        return brushToString(this.i.ma);
    }
    set xAxisMinorStroke(v) {
        this.i.ma = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to minor gridlines along the Y-axis.
        */
    get yAxisMinorStroke() {
        return brushToString(this.i.mh);
    }
    set yAxisMinorStroke(v) {
        this.i.mh = stringToBrush(v);
    }
    /**
         * Gets or sets the angle of rotation for labels along the X-axis.
        */
    get xAxisLabelAngle() {
        return this.i.hy;
    }
    set xAxisLabelAngle(v) {
        this.i.hy = +v;
    }
    /**
         * Gets or sets the angle of rotation for labels along the Y-axis.
        */
    get yAxisLabelAngle() {
        return this.i.ig;
    }
    set yAxisLabelAngle(v) {
        this.i.ig = +v;
    }
    /**
         * Gets or sets the distance between the X-axis and the bottom of the chart.
        */
    get xAxisExtent() {
        return this.i.hx;
    }
    set xAxisExtent(v) {
        this.i.hx = +v;
    }
    /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        */
    get yAxisExtent() {
        return this.i.ie;
    }
    set yAxisExtent(v) {
        this.i.ie = +v;
    }
    /**
         * Gets or sets the angle of rotation for the X-axis title.
        */
    get xAxisTitleAngle() {
        return this.i.h8;
    }
    set xAxisTitleAngle(v) {
        this.i.h8 = +v;
    }
    /**
         * Gets or sets the angle of rotation for the Y-axis title.
        */
    get yAxisTitleAngle() {
        return this.i.ir;
    }
    set yAxisTitleAngle(v) {
        this.i.ir = +v;
    }
    /**
         * Gets or sets whether to invert the direction of the X-axis by placing the first data items on the right side of the chart.
        */
    get xAxisInverted() {
        return this.i.gt;
    }
    set xAxisInverted(v) {
        this.i.gt = ensureBool(v);
    }
    /**
         * Gets or sets whether to invert the direction of the Y-axis by placing the minimum numeric value at the top of the chart.
        *
        * You can use `YAxisInverted` to invert the scale of the y axis like this:
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisInverted="true"
        * >
        *
        * </igx-category-chart>
        * ```
        *
        * The default value of `YAxisInverted` is false.
        */
    get yAxisInverted() {
        return this.i.gu;
    }
    set yAxisInverted(v) {
        this.i.gu = ensureBool(v);
    }
    /**
         * Gets or sets Horizontal alignment of the X-axis title.
        */
    get xAxisTitleAlignment() {
        return this.i.ls;
    }
    set xAxisTitleAlignment(v) {
        this.i.ls = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets Vertical alignment of the Y-axis title.
        */
    get yAxisTitleAlignment() {
        return this.i.mr;
    }
    set yAxisTitleAlignment(v) {
        this.i.mr = ensureEnum(VerticalAlignment_$type, v);
    }
    /**
         * Gets or sets Horizontal alignment of X-axis labels.
        */
    get xAxisLabelHorizontalAlignment() {
        return this.i.lr;
    }
    set xAxisLabelHorizontalAlignment(v) {
        this.i.lr = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets Horizontal alignment of Y-axis labels.
        */
    get yAxisLabelHorizontalAlignment() {
        return this.i.lt;
    }
    set yAxisLabelHorizontalAlignment(v) {
        this.i.lt = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets Vertical alignment of X-axis labels.
        */
    get xAxisLabelVerticalAlignment() {
        return this.i.mp;
    }
    set xAxisLabelVerticalAlignment(v) {
        this.i.mp = ensureEnum(VerticalAlignment_$type, v);
    }
    /**
         * Gets or sets Vertical alignment of Y-axis labels.
        */
    get yAxisLabelVerticalAlignment() {
        return this.i.mq;
    }
    set yAxisLabelVerticalAlignment(v) {
        this.i.mq = ensureEnum(VerticalAlignment_$type, v);
    }
    /**
         * Gets or sets Visibility of X-axis labels.
        */
    get xAxisLabelVisibility() {
        return this.i.mu;
    }
    set xAxisLabelVisibility(v) {
        this.i.mu = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets Visibility of Y-axis labels.
        */
    get yAxisLabelVisibility() {
        return this.i.mv;
    }
    set yAxisLabelVisibility(v) {
        this.i.mv = ensureEnum(Visibility_$type, v);
    }
    /**
         * The location of Y-axis labels, relative to the plot area.
        */
    get yAxisLabelLocation() {
        return this.i.gq;
    }
    set yAxisLabelLocation(v) {
        this.i.gq = ensureEnum(AxisLabelsLocation_$type, v);
    }
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    getScaledValueX(unscaledValue) {
        let iv = this.i.ht(unscaledValue);
        return (iv);
    }
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    getUnscaledValueX(scaledValue) {
        let iv = this.i.hv(scaledValue);
        return (iv);
    }
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    getScaledValueY(unscaledValue) {
        let iv = this.i.hu(unscaledValue);
        return (iv);
    }
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    getUnscaledValueY(scaledValue) {
        let iv = this.i.hw(scaledValue);
        return (iv);
    }
}
IgxXYChartComponent.propDecorators = {
    "xAxisFormatLabel": [{ type: Input },],
    "yAxisFormatLabel": [{ type: Input },],
    "xAxisLabelLeftMargin": [{ type: Input },],
    "xAxisLabelTopMargin": [{ type: Input },],
    "xAxisLabelRightMargin": [{ type: Input },],
    "xAxisLabelBottomMargin": [{ type: Input },],
    "yAxisLabelLeftMargin": [{ type: Input },],
    "yAxisLabelTopMargin": [{ type: Input },],
    "yAxisLabelRightMargin": [{ type: Input },],
    "yAxisLabelBottomMargin": [{ type: Input },],
    "xAxisLabelTextColor": [{ type: Input },],
    "yAxisLabelTextColor": [{ type: Input },],
    "xAxisTitleMargin": [{ type: Input },],
    "yAxisTitleMargin": [{ type: Input },],
    "xAxisTitleLeftMargin": [{ type: Input },],
    "yAxisTitleLeftMargin": [{ type: Input },],
    "xAxisTitleTopMargin": [{ type: Input },],
    "yAxisTitleTopMargin": [{ type: Input },],
    "xAxisTitleRightMargin": [{ type: Input },],
    "yAxisTitleRightMargin": [{ type: Input },],
    "xAxisTitleBottomMargin": [{ type: Input },],
    "yAxisTitleBottomMargin": [{ type: Input },],
    "xAxisTitleTextColor": [{ type: Input },],
    "yAxisTitleTextColor": [{ type: Input },],
    "xAxisLabelTextStyle": [{ type: Input },],
    "yAxisLabelTextStyle": [{ type: Input },],
    "xAxisTitleTextStyle": [{ type: Input },],
    "yAxisTitleTextStyle": [{ type: Input },],
    "xAxisLabel": [{ type: Input },],
    "yAxisLabel": [{ type: Input },],
    "xAxisMajorStroke": [{ type: Input },],
    "yAxisMajorStroke": [{ type: Input },],
    "xAxisMajorStrokeThickness": [{ type: Input },],
    "yAxisMajorStrokeThickness": [{ type: Input },],
    "xAxisMinorStrokeThickness": [{ type: Input },],
    "yAxisMinorStrokeThickness": [{ type: Input },],
    "xAxisStrip": [{ type: Input },],
    "yAxisStrip": [{ type: Input },],
    "xAxisStroke": [{ type: Input },],
    "yAxisStroke": [{ type: Input },],
    "xAxisStrokeThickness": [{ type: Input },],
    "yAxisStrokeThickness": [{ type: Input },],
    "xAxisTickLength": [{ type: Input },],
    "yAxisTickLength": [{ type: Input },],
    "xAxisTickStroke": [{ type: Input },],
    "yAxisTickStroke": [{ type: Input },],
    "xAxisTickStrokeThickness": [{ type: Input },],
    "yAxisTickStrokeThickness": [{ type: Input },],
    "xAxisTitle": [{ type: Input },],
    "yAxisTitle": [{ type: Input },],
    "xAxisMinorStroke": [{ type: Input },],
    "yAxisMinorStroke": [{ type: Input },],
    "xAxisLabelAngle": [{ type: Input },],
    "yAxisLabelAngle": [{ type: Input },],
    "xAxisExtent": [{ type: Input },],
    "yAxisExtent": [{ type: Input },],
    "xAxisTitleAngle": [{ type: Input },],
    "yAxisTitleAngle": [{ type: Input },],
    "xAxisInverted": [{ type: Input },],
    "yAxisInverted": [{ type: Input },],
    "xAxisTitleAlignment": [{ type: Input },],
    "yAxisTitleAlignment": [{ type: Input },],
    "xAxisLabelHorizontalAlignment": [{ type: Input },],
    "yAxisLabelHorizontalAlignment": [{ type: Input },],
    "xAxisLabelVerticalAlignment": [{ type: Input },],
    "yAxisLabelVerticalAlignment": [{ type: Input },],
    "xAxisLabelVisibility": [{ type: Input },],
    "yAxisLabelVisibility": [{ type: Input },],
    "yAxisLabelLocation": [{ type: Input },],
};
//# sourceMappingURL=igx-xy-chart-component.js.map