import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { ConsolidatedItemsPosition, ConsolidatedItemsPosition_$type } from './ConsolidatedItemsPosition';
import { IgxHorizontalAnchoredCategorySeriesComponent } from './igx-horizontal-anchored-category-series-component';
import { IgxAnchoredCategorySeriesComponent } from './igx-anchored-category-series-component';
import { IgxCategorySeriesComponent } from './igx-category-series-component';
import { IgxMarkerSeriesComponent } from './igx-marker-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { ColumnSeries } from "./ColumnSeries";
import { ensureEnum, toPoint, fromRect } from "./componentUtil";
/**
 * Represents a IgxDataChartComponent column series.
 * Compare values across categories by using vertical rectangles.Use it when the order of categories is not important or for displaying
 * item counts such as a histogram.
*/
export var IgxColumnSeriesComponent_PROVIDERS = [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }];
var IgxColumnSeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxColumnSeriesComponent, _super);
    function IgxColumnSeriesComponent() {
        return _super.call(this) || this;
    }
    IgxColumnSeriesComponent.prototype.createImplementation = function () {
        return new ColumnSeries();
    };
    Object.defineProperty(IgxColumnSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnSeriesComponent.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: /**
             * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
            */
        function () {
            return this.i.p0;
        },
        set: function (v) {
            this.i.p0 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnSeriesComponent.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: /**
             * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
            */
        function () {
            return this.i.p1;
        },
        set: function (v) {
            this.i.p1 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnSeriesComponent.prototype, "consolidatedColumnVerticalPosition", {
        /**
         * The positioning logic to use for columns which have been consolidated into a single visual element.
        */
        get: /**
             * The positioning logic to use for columns which have been consolidated into a single visual element.
            */
        function () {
            return this.i.py;
        },
        set: function (v) {
            this.i.py = ensureEnum(ConsolidatedItemsPosition_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    IgxColumnSeriesComponent.prototype.getSeriesValueBoundingBox = /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    function (world) {
        var iv = this.i.k9(toPoint(world));
        return fromRect(iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
    IgxColumnSeriesComponent.prototype.getItemSpan = /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
    function () {
        var iv = this.i.d7();
        return (iv);
    };
    IgxColumnSeriesComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-column-series',
                    template: "",
                    providers: [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxColumnSeriesComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxColumnSeriesComponent.ctorParameters = function () { return []; };
    IgxColumnSeriesComponent.propDecorators = {
        "radiusX": [{ type: Input },],
        "radiusY": [{ type: Input },],
        "consolidatedColumnVerticalPosition": [{ type: Input },],
    };
    return IgxColumnSeriesComponent;
}(IgxHorizontalAnchoredCategorySeriesComponent));
export { IgxColumnSeriesComponent };
//# sourceMappingURL=igx-column-series-component.js.map