import * as tslib_1 from "tslib";
import { EventEmitter, Output, TemplateRef, Component, ViewContainerRef, Injector, ComponentFactoryResolver, Renderer2, ViewChild, QueryList, ElementRef, Inject, Input, NgZone, ChangeDetectionStrategy, ViewChildren } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { AngularRenderer, AngularWrapper } from './angular-renderer';
import { TypeRegistrar } from './type';
import { FinancialChart } from './FinancialChart';
import { FinancialChartType, FinancialChartType_$type } from './FinancialChartType';
import { fromBrushCollection, toBrushCollection, ensureEnum, ensureBool } from './componentUtil';
import { IgxXYChartComponent } from './igx-xy-chart-component';
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
import { DataSeriesType } from './DataSeriesType';
import { DataContext } from './igx-data-context';
import { FinancialChartVolumeType, FinancialChartVolumeType_$type } from './FinancialChartVolumeType';
import { FinancialChartXAxisMode, FinancialChartXAxisMode_$type } from './FinancialChartXAxisMode';
import { FinancialChartYAxisMode, FinancialChartYAxisMode_$type } from './FinancialChartYAxisMode';
import { HorizontalAlignment, HorizontalAlignment_$type } from './HorizontalAlignment';
import { AxisLabelsLocation, AxisLabelsLocation_$type } from './AxisLabelsLocation';
import { FinancialChartZoomSliderType, FinancialChartZoomSliderType_$type } from './FinancialChartZoomSliderType';
import { IgxFinancialChartDefaultTemplatesComponent } from './igx-financial-chart-default-templates';
import { IgxTemplateContentComponent } from './igx-template-content-component';
import { delegateCombine } from './type';
import { FinancialIndicatorTypeCollection } from './igx-financial-indicator-type-collection';
import { FinancialIndicatorTypeCollection as FinancialIndicatorTypeCollection_internal } from './FinancialIndicatorTypeCollection';
import { SyncableObservableCollection$1 } from './SyncableObservableCollection$1';
import { FinancialIndicatorType_$type } from './FinancialIndicatorType';
import { FinancialOverlayTypeCollection } from './igx-financial-overlay-type-collection';
import { FinancialOverlayTypeCollection as FinancialOverlayTypeCollection_internal } from './FinancialOverlayTypeCollection';
import { FinancialOverlayType_$type } from './FinancialOverlayType';
import { IndicatorDisplayTypeCollection } from './igx-indicator-display-type-collection';
import { IndicatorDisplayTypeCollection as IndicatorDisplayTypeCollection_internal } from './IndicatorDisplayTypeCollection';
import { IndicatorDisplayType_$type } from './IndicatorDisplayType';
import { FinancialChartRangeSelectorOptionCollection } from './igx-financial-chart-range-selector-option-collection';
import { FinancialChartRangeSelectorOptionCollection as FinancialChartRangeSelectorOptionCollection_internal } from './FinancialChartRangeSelectorOptionCollection';
import { FinancialChartRangeSelectorOption_$type } from './FinancialChartRangeSelectorOption';
import { FinancialChartCustomIndicatorArgs } from './igx-financial-chart-custom-indicator-args';
import { CustomIndicatorNameCollection as CustomIndicatorNameCollection_internal } from './CustomIndicatorNameCollection';
import { CustomIndicatorNameCollection } from './igx-custom-indicator-name-collection';
import { String_$type } from './type';
export var IgxFinancialChartComponent_PROVIDERS = [];
/**
 * Represents a chart with an ordinal X-axis and a numeric Y-axis.
*
* **Ignite UI for Angular Financial Chart** - [Documentation](http://linkToSomewhere/FinancialChart/Overview)
*
* The Ignite UI Financial Chart is a lightweight, highly performant chart. It can be easily configured to display category data using an extremely simple and intuitive API. It offers multiple ways for the user to visualize data, including several display modes for price and volume, and many financial indicators.
*
* Example:
*
* ```html
* <igx-financial-chart [dataSource]="data"
* 					 width="850px" height="600px">
* </igx-financial-chart>
* ```
*/
var IgxFinancialChartComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxFinancialChartComponent, _super);
    function IgxFinancialChartComponent(renderer, _elRef, document, ngZone, injector, componentFactoryResolver) {
        var _this = _super.call(this) || this;
        _this.renderer = renderer;
        _this._elRef = _elRef;
        _this.document = document;
        _this.ngZone = ngZone;
        _this.injector = injector;
        _this.componentFactoryResolver = componentFactoryResolver;
        _this._wrapper = null;
        _this._dataSource = null;
        _this._defaultTooltips = null;
        _this._indicatorTypes = null;
        _this._overlayTypes = null;
        _this._indicatorDisplayTypes = null;
        _this._rangeSelectorOptions = null;
        _this._customIndicatorNames = null;
        _this._applyCustomIndicators = null;
        _this._zoneRunner = function (act) { return ngZone.run(act); };
        _this.container = renderer.createElement("div");
        renderer.appendChild(_elRef.element.nativeElement, _this.container);
        renderer.setStyle(_this.container, "display", "block");
        renderer.setStyle(_this.container, "width", "100%");
        renderer.setStyle(_this.container, "height", "100%");
        var root;
        root = _this.container;
        if (_this.container != null) {
            root = _this.container;
        }
        var ren = new AngularRenderer(root, _this.renderer, _this.document, _this.ngZone, true, DataChartStylingDefaults);
        _this._wrapper = ren;
        var chart = _this.i;
        _this._chart = chart;
        if (chart.xAxis) {
            _this.rewrapAxis(chart.xAxis);
        }
        if (chart.yAxis) {
            _this.rewrapAxis(chart.yAxis);
        }
        if (chart.volumeAxis) {
            _this.rewrapAxis(chart.volumeAxis);
        }
        if (chart.volumeXAxis) {
            _this.rewrapAxis(chart.volumeXAxis);
        }
        if (chart.indicatorAxis) {
            _this.rewrapAxis(chart.indicatorAxis);
        }
        if (chart.indicatorXAxis) {
            _this.rewrapAxis(chart.indicatorXAxis);
        }
        if (chart.zoomSliderAxis) {
            _this.rewrapAxis(chart.zoomSliderAxis);
        }
        if (chart.zoomSliderXAxis) {
            _this.rewrapAxis(chart.zoomSliderXAxis);
        }
        chart.provideContainer(ren);
        _this.bindData();
        chart.notifyResized();
        ren.addSizeWatcher(function () {
            _this._checkToolbarSize();
            _this._chart.notifyResized();
        });
        return _this;
    }
    Object.defineProperty(IgxFinancialChartComponent.prototype, "height", {
        get: function () {
            return this._height;
        },
        set: function (value) {
            this._height = value;
            this.renderer.setStyle(this._elRef.element.nativeElement, "height", value);
            this._chart.notifyResized();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "width", {
        get: function () {
            return this._width;
        },
        set: function (value) {
            this._width = value;
            this.renderer.setStyle(this._elRef.element.nativeElement, "width", value);
            this._chart.notifyResized();
        },
        enumerable: true,
        configurable: true
    });
    IgxFinancialChartComponent.prototype._checkToolbarSize = function () {
        if (this._toolbarElement) {
            var start = this._toolbarElement.nativeElement;
            if (start.children.length == 1) {
                start = start.children[0];
            }
            var toolbarRoot = start.querySelector(".financialChartToolbar");
            var rootRect = toolbarRoot.getBoundingClientRect();
            var hideRemaining = false;
            for (var i = 0; i < toolbarRoot.children.length; i++) {
                var child = toolbarRoot.children[i];
                if (child.nodeType == Node.ELEMENT_NODE) {
                    if (!hideRemaining) {
                        child.style.display = "";
                    }
                    var childRect = child.getBoundingClientRect();
                    if (hideRemaining ||
                        childRect.left + childRect.width >
                            rootRect.left + rootRect.width) {
                        child.style.display = "none";
                        hideRemaining = true;
                    }
                    else {
                        child.style.display = "";
                    }
                }
            }
        }
    };
    IgxFinancialChartComponent.prototype.ngOnDestroy = function () {
        this._chart.destroy();
        this._wrapper.destroy();
    };
    IgxFinancialChartComponent.prototype.onDocumentClick = function (ev) {
        var classList = ev.target.classList;
        var classes = [];
        if (classList) {
            for (var i = 0; i < classList.length; i++) {
                classes.push(classList[i]);
            }
        }
        this._chart.onDocumentClick(classes);
    };
    IgxFinancialChartComponent.prototype.rewrapAxis = function (axis) {
        var axisName = axis.$type.name;
        var componentName = "Igx" + axisName + "Component";
        if (TypeRegistrar.isRegistered(componentName)) {
            var x = TypeRegistrar.create(componentName);
            x._implementation = axis;
            axis.externalObject = x;
        }
        else {
            throw new Error("Axis type not loaded: " + componentName);
        }
    };
    IgxFinancialChartComponent.prototype.createImplementation = function () {
        return new FinancialChart();
    };
    Object.defineProperty(IgxFinancialChartComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgxFinancialChartComponent.prototype.createSeriesComponent = function (type) {
        if (TypeRegistrar.isRegistered(type)) {
            var s = TypeRegistrar.create(type);
            s.owner = this;
            return s;
        }
        else {
            //we shouldn't get here, hopefully.
            throw Error("series type not loaded: " + type);
        }
    };
    IgxFinancialChartComponent.prototype.createIndicator = function (typeName) {
        return this.createSeriesComponent("Igx" + typeName + "Component");
    };
    IgxFinancialChartComponent.prototype.createOverlay = function (typeName) {
        return this.createSeriesComponent("Igx" + typeName + "Component");
    };
    IgxFinancialChartComponent.prototype.createSeries = function (type) {
        switch (type) {
            case DataSeriesType.Area:
                return this.createSeriesComponent('IgxAreaSeriesComponent');
            case DataSeriesType.Column:
                return this.createSeriesComponent('IgxColumnSeriesComponent');
            case DataSeriesType.Line:
                return this.createSeriesComponent('IgxLineSeriesComponent');
            case DataSeriesType.FinancialPrice:
                return this.createSeriesComponent('IgxFinancialPriceSeriesComponent');
            default:
                return this.createSeriesComponent('IgxColumnSeriesComponent');
        }
    };
    IgxFinancialChartComponent.prototype.createXAxis = function (type) {
        switch (type) {
            case FinancialChartXAxisMode.Ordinal:
                if (TypeRegistrar.isRegistered("IgxOrdinalTimeXAxisComponent")) {
                    return TypeRegistrar.create("IgxOrdinalTimeXAxisComponent");
                }
                else if (TypeRegistrar.isRegistered("IgxTimeXAxisComponent")) {
                    return TypeRegistrar.create("IgxTimeXAxisComponent");
                }
                else {
                    throw new Error("not valid axes components loaded");
                }
            case FinancialChartXAxisMode.Time:
                if (TypeRegistrar.isRegistered("IgxTimeXAxisComponent")) {
                    return TypeRegistrar.create("IgxTimeXAxisComponent");
                }
                else if (TypeRegistrar.isRegistered("IgxOrdinalTimeXAxisComponent")) {
                    return TypeRegistrar.create("IgxOrdinalTimeXAxisComponent");
                }
                else {
                    throw new Error("not valid axes components loaded");
                }
        }
    };
    IgxFinancialChartComponent.prototype.createYAxis = function (type) {
        switch (type) {
            case FinancialChartYAxisMode.Numeric:
                if (TypeRegistrar.isRegistered("IgxNumericYAxisComponent")) {
                    return TypeRegistrar.create("IgxNumericYAxisComponent");
                }
                else if (TypeRegistrar.isRegistered("IgxPercentChangeYAxisComponent")) {
                    return TypeRegistrar.create("IgxPercentChangeYAxisComponent");
                }
                else {
                    throw new Error("not valid axes components loaded");
                }
            case FinancialChartYAxisMode.PercentChange:
                if (TypeRegistrar.isRegistered("IgxPercentChangeYAxisComponent")) {
                    return TypeRegistrar.create("IgxPercentChangeYAxisComponent");
                }
                else if (TypeRegistrar.isRegistered("IgxNumericYAxisComponent")) {
                    return TypeRegistrar.create("IgxNumericYAxisComponent");
                }
                else {
                    throw new Error("not valid axes components loaded");
                }
        }
    };
    Object.defineProperty(IgxFinancialChartComponent.prototype, "dataSource", {
        get: function () {
            return this._dataSource;
        },
        set: function (value) {
            this._dataSource = value;
            this.bindData();
        },
        enumerable: true,
        configurable: true
    });
    IgxFinancialChartComponent.prototype.bindData = function () {
        if (this._chart != null && this._chart !== undefined) {
            this._chart.itemsSource = this._dataSource;
        }
    };
    IgxFinancialChartComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (TypeRegistrar.isRegistered("IgxDataChartDefaultTooltipsComponent")) {
            var c = TypeRegistrar.get("IgxDataChartDefaultTooltipsComponent");
            var cf = this.componentFactoryResolver.resolveComponentFactory(c);
            //let cr = cf.create(this.injector);
            var cr_1 = this._dynamicContent.createComponent(cf);
            this._defaultTooltips = cr_1;
            cr_1.instance.onContentReady.subscribe(function () {
                _this._onDefaultTooltipsReady(cr_1);
            });
            this.container.appendChild(cr_1.location.nativeElement);
        }
        var context = this._chart.getContext();
        var toolbarContext = context.vm.toolbar;
        toolbarContext.vm.financialChartChartTypePicker.template = this.chartTypePickerTemplate ? this.chartTypePickerTemplate : this._defaultTemplates.financialChartChartTypePickerTemplate;
        toolbarContext.vm.financialChartChartTypePicker.vm.notifyChanged = function () { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartIndicatorPicker.template = this.indicatorPickerTemplate ? this.indicatorPickerTemplate : this._defaultTemplates.financialChartIndicatorPickerTemplate;
        toolbarContext.vm.financialChartIndicatorPicker.vm.notifyChanged = function () { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartOverlayPicker.template = this.overlayPickerTemplate ? this.overlayPickerTemplate : this._defaultTemplates.financialChartOverlayPickerTemplate;
        toolbarContext.vm.financialChartOverlayPicker.vm.notifyChanged = function () { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartRangeSelector.template = this.rangeSelectorTemplate ? this.rangeSelectorTemplate : this._defaultTemplates.financialChartRangeSelectorTemplate;
        toolbarContext.vm.financialChartRangeSelector.vm.notifyChanged = function () { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartTrendLineTypePicker.template = this.trendlinePickerTemplate ? this.trendlinePickerTemplate : this._defaultTemplates.financialChartTrendlinePickerTemplate;
        toolbarContext.vm.financialChartTrendLineTypePicker.vm.notifyChanged = function () { toolbarArea.context = toolbarContext; };
        toolbarContext.vm.financialChartVolumeTypePicker.template = this.volumeTypePickerTemplate ? this.volumeTypePickerTemplate : this._defaultTemplates.financialChartVolumeTypePickerTemplate;
        toolbarContext.vm.financialChartVolumeTypePicker.vm.notifyChanged = function () { toolbarArea.context = toolbarContext; };
        toolbarContext.template = this.toolbarTemplate ? this.toolbarTemplate : this._defaultTemplates.financialChartToolbarTemplate;
        var toolContainer = toolbarContext.container.rootWrapper.getNativeElement();
        var toolbarArea = this._templates.toArray()[0];
        var mainArea = this._templates.toArray()[1];
        toolbarArea.context = toolbarContext;
        toolbarArea.template = toolbarContext.template;
        var ele = this._toolbarElement.nativeElement;
        ele.style.width = "100%";
        ele.style.height = "100%";
        if (ele.parentElement != null) {
            ele.parentElement.removeChild(ele);
        }
        toolContainer.appendChild(ele);
        this.renderer.setStyle(ele, "display", "");
        var mainContainer = context.container.rootWrapper.getNativeElement();
        var indicatorContainer = context.indicatorsContainer.rootWrapper.getNativeElement();
        var volumeContainer = context.volumeContainer.rootWrapper.getNativeElement();
        var zoomSliderContainer = context.zoomContainer.rootWrapper.getNativeElement();
        var main = mainArea.viewContainer.element.nativeElement;
        var templateMain = main.querySelector(".financialChartPrice");
        var templateToolbar = main.querySelector(".financialChartToolbar");
        var templateIndicator = main.querySelector(".financialChartIndicators");
        var templateVolume = main.querySelector(".financialChartVolume");
        var templateZoomSlider = main.querySelector(".financialChartZoomSlider");
        var grid = main.querySelector(".financialChartMainGrid");
        var gridWrapper = new AngularWrapper(grid, this.renderer, this.ngZone);
        templateMain.appendChild(mainContainer);
        templateToolbar.appendChild(toolContainer);
        templateIndicator.appendChild(indicatorContainer);
        templateVolume.appendChild(volumeContainer);
        templateZoomSlider.appendChild(zoomSliderContainer);
        this._mainElement.nativeElement.parentElement.removeChild(this._mainElement.nativeElement);
        this.container.appendChild(this._mainElement.nativeElement);
        this._chart.provideGrid(gridWrapper);
        this._checkToolbarSize();
    };
    IgxFinancialChartComponent.prototype._createZoomSlider = function (hostEle) {
        if (!TypeRegistrar.isRegistered("IgxZoomSliderComponent")) {
            //shouldn't happen.
            throw new Error("zoom slider component isn't loaded");
        }
        var t = TypeRegistrar.get("IgxZoomSliderComponent");
        var cf = this.componentFactoryResolver.resolveComponentFactory(t);
        var cr = this._dynamicContent.createComponent(cf);
        var ele = cr.location.nativeElement;
        ele.style.width = "100%";
        ele.style.height = "100%";
        cr.instance.width = "100%";
        cr.instance.height = "100%";
        if (ele.parentElement !== null) {
            ele.parentElement.removeChild(ele);
        }
        hostEle.appendChild(ele);
        return cr.instance;
    };
    IgxFinancialChartComponent.prototype.createTooltip = function () {
        if (!TypeRegistrar.isRegistered("IgxTooltipContainerComponent")) {
            return null;
        }
        var t = TypeRegistrar.get("IgxTooltipContainerComponent");
        var cf = this.componentFactoryResolver.resolveComponentFactory(t);
        //let cr = cf.create(this.injector);
        var cr = this._dynamicContent.createComponent(cf);
        var ele = cr.location.nativeElement;
        var self = this;
        ele.updateToolTip = function (c) {
            if (c.externalObject) {
                c = c.externalObject;
            }
            else {
                var ext = new DataContext();
                ext._implementation = c;
                c = ext;
            }
            if (ele.parentElement != self.container) {
                if (ele.parentElement != null) {
                    ele.parentElement.removeChild(ele);
                }
                self.container.appendChild(ele);
            }
            cr.instance.context = c;
            ele.style.display = "block";
            return true;
        };
        ele.hideToolTip = function () {
            ele.style.display = "none";
        };
        ele.style.display = "none";
        return cr;
    };
    IgxFinancialChartComponent.prototype._ensureTooltipCreated = function (series) {
        var _this = this;
        series._ensureTooltipCreated(function () { return _this.createTooltip(); }, function (ele) {
            var wrapper = new AngularWrapper(ele, _this.renderer, _this.ngZone);
            wrapper.updateToolTip = ele.updateToolTip;
            wrapper.hideToolTip = ele.hideToolTip;
            return wrapper;
        });
    };
    // private _createXAxis(): any {
    //     let x = new IgxCategoryXAxisComponent();
    //     return x.i;
    // }
    // private _createYAxis(): any {
    //     let y = new IgxNumericYAxisComponent();
    //     return y.i;
    // }
    // private _createXAxis(): any {
    //     let x = new IgxCategoryXAxisComponent();
    //     return x.i;
    // }
    // private _createYAxis(): any {
    //     let y = new IgxNumericYAxisComponent();
    //     return y.i;
    // }
    IgxFinancialChartComponent.prototype._ensureDefaultTooltip = 
    // private _createXAxis(): any {
    //     let x = new IgxCategoryXAxisComponent();
    //     return x.i;
    // }
    // private _createYAxis(): any {
    //     let y = new IgxNumericYAxisComponent();
    //     return y.i;
    // }
    function (series) {
        if (this._defaultTooltips == null) {
            return;
        }
        this._defaultTooltips.instance["ensureDefaultTooltip"](series);
    };
    IgxFinancialChartComponent.prototype._onDefaultTooltipsReady = function (cr) {
        if (this.i.dataChart) {
            var currSeries = this.i.dataChart.series;
            for (var i = 0; i < currSeries.count; i++) {
                if (currSeries.item(i).externalObject.showDefaultTooltip) {
                    this._ensureDefaultTooltip(currSeries.item(i).externalObject);
                }
            }
        }
    };
    Object.defineProperty(IgxFinancialChartComponent.prototype, "leftMargin", {
        get: function () {
            return this.i.bw;
        },
        set: function (v) {
            this.i.bw = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "isHorizontalZoomEnabled", {
        get: function () {
            return this.i.ay;
        },
        set: function (v) {
            this.i.ay = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "toolbarHeight", {
        get: function () {
            return this.i.qi;
        },
        set: function (v) {
            this.i.qi = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisIsLogarithmic", {
        /**
         * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
         * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
        */
        get: /**
             * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
             * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
            */
        function () {
            return this.i.pw;
        },
        set: function (v) {
            this.i.pw = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisLogarithmBase", {
        /**
         * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
         * This property is effective only when YAxisIsLogarithmic is true.
        */
        get: /**
             * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
             * This property is effective only when YAxisIsLogarithmic is true.
            */
        function () {
            return this.i.q8;
        },
        set: function (v) {
            this.i.q8 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisInterval", {
        /**
         * Gets or sets the distance between each label and grid line along the Y-axis.
        */
        get: /**
             * Gets or sets the distance between each label and grid line along the Y-axis.
            */
        function () {
            return this.i.qm;
        },
        set: function (v) {
            this.i.qm = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisMinimumValue", {
        /**
         * Gets or sets the data value corresponding to the minimum value of the Y-axis.
        */
        get: /**
             * Gets or sets the data value corresponding to the minimum value of the Y-axis.
            */
        function () {
            return this.i.qo;
        },
        set: function (v) {
            this.i.qo = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisMaximumValue", {
        /**
         * Gets or sets the data value corresponding to the maximum value of the Y-axis.
        */
        get: /**
             * Gets or sets the data value corresponding to the maximum value of the Y-axis.
            */
        function () {
            return this.i.qn;
        },
        set: function (v) {
            this.i.qn = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisMinorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines along the Y-axis.
        */
        get: /**
             * Gets or sets the frequency of displayed minor lines along the Y-axis.
            */
        function () {
            return this.i.qp;
        },
        set: function (v) {
            this.i.qp = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisActualMinimum", {
        /**
         * Gets the current minimum value for the Y-axis.
        */
        get: /**
             * Gets the current minimum value for the Y-axis.
            */
        function () {
            return this.i.ql;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisActualMaximum", {
        /**
         * Gets the current maximum value for the Y-axis.
        */
        get: /**
             * Gets the current maximum value for the Y-axis.
            */
        function () {
            return this.i.qk;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "volumeType", {
        /**
         * The type of series to display in the volume pane.
        */
        get: /**
             * The type of series to display in the volume pane.
            */
        function () {
            return this.i.n2;
        },
        set: function (v) {
            this.i.n2 = ensureEnum(FinancialChartVolumeType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "xAxisMode", {
        /**
         * The scaling mode of the X-axis.
        */
        get: /**
             * The scaling mode of the X-axis.
            */
        function () {
            return this.i.n4;
        },
        set: function (v) {
            this.i.n4 = ensureEnum(FinancialChartXAxisMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisMode", {
        /**
         * The scaling mode of the Y-axis.
        */
        get: /**
             * The scaling mode of the Y-axis.
            */
        function () {
            return this.i.n6;
        },
        set: function (v) {
            this.i.n6 = ensureEnum(FinancialChartYAxisMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "isToolbarVisible", {
        /**
         * A boolean property controlling the visibility of the toolbar.
        */
        get: /**
             * A boolean property controlling the visibility of the toolbar.
            */
        function () {
            return this.i.pr;
        },
        set: function (v) {
            this.i.pr = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "chartType", {
        /**
         * The type of price series to display in the main chart.
        */
        get: /**
             * The type of price series to display in the main chart.
            */
        function () {
            return this.i.nx;
        },
        set: function (v) {
            this.i.nx = ensureEnum(FinancialChartType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisLabelHorizontalAlignment", {
        /**
         * Gets or sets Horizontal alignment of Y-axis labels.
        */
        get: /**
             * Gets or sets Horizontal alignment of Y-axis labels.
            */
        function () {
            return this.i.lt;
        },
        set: function (v) {
            this.i.lt = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "isWindowSyncedToVisibleRange", {
        /**
         * A boolean indicating whether the chart should automatically zoom in vertically on the currently visible range of data.
         * When this property is set to true, panning and zooming along the X-axis will result in a corresponding zoom on the Y-axis, so that the visible range of data fills the zoom window as fully as possible.
        */
        get: /**
             * A boolean indicating whether the chart should automatically zoom in vertically on the currently visible range of data.
             * When this property is set to true, panning and zooming along the X-axis will result in a corresponding zoom on the Y-axis, so that the visible range of data fills the zoom window as fully as possible.
            */
        function () {
            return this.i.ps;
        },
        set: function (v) {
            this.i.ps = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorTypes", {
        /**
         * A collection indicating what financial indicator types to display on the Financial Chart.
        */
        get: /**
             * A collection indicating what financial indicator types to display on the Financial Chart.
            */
        function () {
            if (this._indicatorTypes === null) {
                var coll = new FinancialIndicatorTypeCollection();
                var innerColl = this.i.ob;
                var wasNull = false;
                if (!innerColl) {
                    wasNull = true;
                    innerColl = new FinancialIndicatorTypeCollection_internal(0);
                }
                this._indicatorTypes = coll._fromInner(innerColl);
                if (wasNull) {
                    this.i.ob = innerColl;
                }
            }
            return this._indicatorTypes;
        },
        set: function (v) {
            if (this._indicatorTypes !== null) {
                this._indicatorTypes._setSyncTarget(null);
                this._indicatorTypes = null;
            }
            var coll = new FinancialIndicatorTypeCollection();
            this._indicatorTypes = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(FinancialIndicatorType_$type);
            var innerColl = this.i.ob;
            var wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new FinancialIndicatorTypeCollection_internal(0);
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._indicatorTypes._setSyncTarget(syncColl);
            if (wasNull) {
                this.i.ob = innerColl;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "overlayTypes", {
        /**
         * A collection indicating what financial overlay types to display on the Financial Chart.
        */
        get: /**
             * A collection indicating what financial overlay types to display on the Financial Chart.
            */
        function () {
            if (this._overlayTypes === null) {
                var coll = new FinancialOverlayTypeCollection();
                var innerColl = this.i.od;
                var wasNull = false;
                if (!innerColl) {
                    wasNull = true;
                    innerColl = new FinancialOverlayTypeCollection_internal(0);
                }
                this._overlayTypes = coll._fromInner(innerColl);
                if (wasNull) {
                    this.i.od = innerColl;
                }
            }
            return this._overlayTypes;
        },
        set: function (v) {
            if (this._overlayTypes !== null) {
                this._overlayTypes._setSyncTarget(null);
                this._overlayTypes = null;
            }
            var coll = new FinancialOverlayTypeCollection();
            this._overlayTypes = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(FinancialOverlayType_$type);
            var innerColl = this.i.od;
            var wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new FinancialOverlayTypeCollection_internal(0);
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._overlayTypes._setSyncTarget(syncColl);
            if (wasNull) {
                this.i.od = innerColl;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisAbbreviateLargeNumbers", {
        /**
         * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
        */
        get: /**
             * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
            */
        function () {
            return this.i.pv;
        },
        set: function (v) {
            this.i.pv = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "resolution", {
        /**
         * Gets or sets the rendering resolution for all series in this chart.
         * Where n = Resolution, for every n horizontal pixels, combine all items into a single datapoint.  When Resolution = 0, all datapoints will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
        */
        get: /**
             * Gets or sets the rendering resolution for all series in this chart.
             * Where n = Resolution, for every n horizontal pixels, combine all items into a single datapoint.  When Resolution = 0, all datapoints will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
            */
        function () {
            return this.i.by;
        },
        set: function (v) {
            this.i.by = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "yAxisLabelLocation", {
        /**
         * The location of Y-axis labels, relative to the plot area.
        */
        get: /**
             * The location of Y-axis labels, relative to the plot area.
            */
        function () {
            return this.i.gq;
        },
        set: function (v) {
            this.i.gq = ensureEnum(AxisLabelsLocation_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "zoomSliderType", {
        /**
         * The type of series to display in the zoom slider pane.
        */
        get: /**
             * The type of series to display in the zoom slider pane.
            */
        function () {
            return this.i.n9;
        },
        set: function (v) {
            this.i.n9 = ensureEnum(FinancialChartZoomSliderType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "negativeBrushes", {
        /**
         * Gets or sets the palette used for coloring negative items of Waterfall chart type.
        */
        get: /**
             * Gets or sets the palette used for coloring negative items of Waterfall chart type.
            */
        function () {
            return fromBrushCollection(this.i.m6);
        },
        set: function (v) {
            this.i.m6 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "negativeOutlines", {
        /**
         * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
        */
        get: /**
             * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
            */
        function () {
            return fromBrushCollection(this.i.m7);
        },
        set: function (v) {
            this.i.m7 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "overlayBrushes", {
        /**
         * Brushes to use for filling financial overlays.
        */
        get: /**
             * Brushes to use for filling financial overlays.
            */
        function () {
            return fromBrushCollection(this.i.m8);
        },
        set: function (v) {
            this.i.m8 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "overlayOutlines", {
        /**
         * Brushes to use for outlining financial overlays.
        */
        get: /**
             * Brushes to use for outlining financial overlays.
            */
        function () {
            return fromBrushCollection(this.i.m9);
        },
        set: function (v) {
            this.i.m9 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "volumeOutlines", {
        /**
         * Brushes to use for outlining volume series in the volume pane.
        */
        get: /**
             * Brushes to use for outlining volume series in the volume pane.
            */
        function () {
            return fromBrushCollection(this.i.nb);
        },
        set: function (v) {
            this.i.nb = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "volumeBrushes", {
        /**
         * Brushes to use for filling volume series in the volume pane.
        */
        get: /**
             * Brushes to use for filling volume series in the volume pane.
            */
        function () {
            return fromBrushCollection(this.i.na);
        },
        set: function (v) {
            this.i.na = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorNegativeBrushes", {
        /**
         * Brushes to use for negative elements in financial indicators.
        */
        get: /**
             * Brushes to use for negative elements in financial indicators.
            */
        function () {
            return fromBrushCollection(this.i.m5);
        },
        set: function (v) {
            this.i.m5 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorBrushes", {
        /**
         * Brushes to use for financial indicators.
        */
        get: /**
             * Brushes to use for financial indicators.
            */
        function () {
            return fromBrushCollection(this.i.m4);
        },
        set: function (v) {
            this.i.m4 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "volumeThickness", {
        /**
         * The outline thickness of volume series in the volume pane.
        */
        get: /**
             * The outline thickness of volume series in the volume pane.
            */
        function () {
            return this.i.qj;
        },
        set: function (v) {
            this.i.qj = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "overlayThickness", {
        /**
         * The outline thickness of financial overlays.
        */
        get: /**
             * The outline thickness of financial overlays.
            */
        function () {
            return this.i.qh;
        },
        set: function (v) {
            this.i.qh = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorThickness", {
        /**
         * The outline or stroke thickness of financial indicators.
        */
        get: /**
             * The outline or stroke thickness of financial indicators.
            */
        function () {
            return this.i.qg;
        },
        set: function (v) {
            this.i.qg = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorDisplayTypes", {
        /**
         * The display types of financial indicators.
        */
        get: /**
             * The display types of financial indicators.
            */
        function () {
            if (this._indicatorDisplayTypes === null) {
                var coll = new IndicatorDisplayTypeCollection();
                var innerColl = this.i.ol;
                var wasNull = false;
                if (!innerColl) {
                    wasNull = true;
                    innerColl = new IndicatorDisplayTypeCollection_internal();
                }
                this._indicatorDisplayTypes = coll._fromInner(innerColl);
                if (wasNull) {
                    this.i.ol = innerColl;
                }
            }
            return this._indicatorDisplayTypes;
        },
        set: function (v) {
            if (this._indicatorDisplayTypes !== null) {
                this._indicatorDisplayTypes._setSyncTarget(null);
                this._indicatorDisplayTypes = null;
            }
            var coll = new IndicatorDisplayTypeCollection();
            this._indicatorDisplayTypes = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(IndicatorDisplayType_$type);
            var innerColl = this.i.ol;
            var wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new IndicatorDisplayTypeCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._indicatorDisplayTypes._setSyncTarget(syncColl);
            if (wasNull) {
                this.i.ol = innerColl;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorPeriod", {
        /**
         * The period of financial indicators, where applicable.
        */
        get: /**
             * The period of financial indicators, where applicable.
            */
        function () {
            return this.i.q3;
        },
        set: function (v) {
            this.i.q3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorMultiplier", {
        /**
         * The multiplier of financial indicators, where applicable.
        */
        get: /**
             * The multiplier of financial indicators, where applicable.
            */
        function () {
            return this.i.qf;
        },
        set: function (v) {
            this.i.qf = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorSmoothingPeriod", {
        /**
         * The smoothing period of financial indicators, where applicable.
        */
        get: /**
             * The smoothing period of financial indicators, where applicable.
            */
        function () {
            return this.i.q6;
        },
        set: function (v) {
            this.i.q6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorShortPeriod", {
        /**
         * The short period of financial indicators, where applicable.
        */
        get: /**
             * The short period of financial indicators, where applicable.
            */
        function () {
            return this.i.q4;
        },
        set: function (v) {
            this.i.q4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorLongPeriod", {
        /**
         * The long period of financial indicators, where applicable.
        */
        get: /**
             * The long period of financial indicators, where applicable.
            */
        function () {
            return this.i.q2;
        },
        set: function (v) {
            this.i.q2 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "indicatorSignalPeriod", {
        /**
         * The signal period of financial indicators, where applicable.
        */
        get: /**
             * The signal period of financial indicators, where applicable.
            */
        function () {
            return this.i.q5;
        },
        set: function (v) {
            this.i.q5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "rangeSelectorOptions", {
        /**
         * A FinancialChartRangeSelectorOptionCollection containing the available range selector options on the toolbar.
        */
        get: /**
             * A FinancialChartRangeSelectorOptionCollection containing the available range selector options on the toolbar.
            */
        function () {
            if (this._rangeSelectorOptions === null) {
                var coll = new FinancialChartRangeSelectorOptionCollection();
                var innerColl = this.i.nt;
                var wasNull = false;
                if (!innerColl) {
                    wasNull = true;
                    innerColl = new FinancialChartRangeSelectorOptionCollection_internal(0);
                }
                this._rangeSelectorOptions = coll._fromInner(innerColl);
                if (wasNull) {
                    this.i.nt = innerColl;
                }
            }
            return this._rangeSelectorOptions;
        },
        set: function (v) {
            if (this._rangeSelectorOptions !== null) {
                this._rangeSelectorOptions._setSyncTarget(null);
                this._rangeSelectorOptions = null;
            }
            var coll = new FinancialChartRangeSelectorOptionCollection();
            this._rangeSelectorOptions = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(FinancialChartRangeSelectorOption_$type);
            var innerColl = this.i.nt;
            var wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new FinancialChartRangeSelectorOptionCollection_internal(0);
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._rangeSelectorOptions._setSyncTarget(syncColl);
            if (wasNull) {
                this.i.nt = innerColl;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "customIndicatorNames", {
        /**
         * The names of custom indicators to add to the chart.
         * When CustomIndicatorNames is set, the ApplyCustomIndicators event will be raised for each custom indicator name.
        */
        get: /**
             * The names of custom indicators to add to the chart.
             * When CustomIndicatorNames is set, the ApplyCustomIndicators event will be raised for each custom indicator name.
            */
        function () {
            if (this._customIndicatorNames === null) {
                var coll = new CustomIndicatorNameCollection();
                var innerColl = this.i.customIndicatorNames;
                var wasNull = false;
                if (!innerColl) {
                    wasNull = true;
                    innerColl = new CustomIndicatorNameCollection_internal(0);
                }
                this._customIndicatorNames = coll._fromInner(innerColl);
                if (wasNull) {
                    this.i.customIndicatorNames = innerColl;
                }
            }
            return this._customIndicatorNames;
        },
        set: function (v) {
            if (this._customIndicatorNames !== null) {
                this._customIndicatorNames._setSyncTarget(null);
                this._customIndicatorNames = null;
            }
            var coll = new CustomIndicatorNameCollection();
            this._customIndicatorNames = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(String_$type);
            var innerColl = this.i.customIndicatorNames;
            var wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new CustomIndicatorNameCollection_internal(0);
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._customIndicatorNames._setSyncTarget(syncColl);
            if (wasNull) {
                this.i.customIndicatorNames = innerColl;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialChartComponent.prototype, "isVerticalZoomEnabled", {
        get: function () {
            return this.i.a3;
        },
        set: function (v) {
            this.i.a3 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    IgxFinancialChartComponent.prototype.provideContainer = function (container) {
        this.i.provideContainer(container);
    };
    IgxFinancialChartComponent.prototype.notifyInsertItem = function (source_, index, newItem) {
        this.i.e9(source_, index, newItem);
    };
    IgxFinancialChartComponent.prototype.notifyRemoveItem = function (source_, index, oldItem) {
        this.i.fa(source_, index, oldItem);
    };
    IgxFinancialChartComponent.prototype.notifyClearItems = function (source_) {
        this.i.e8(source_);
    };
    IgxFinancialChartComponent.prototype.notifySetItem = function (source_, index, oldItem, newItem) {
        this.i.fc(source_, index, oldItem, newItem);
    };
    /**
     * Returns visuals as a serialized string.
    
    */
    /**
         * Returns visuals as a serialized string.
        
        */
    IgxFinancialChartComponent.prototype.exportSerializedVisualData = /**
         * Returns visuals as a serialized string.
        
        */
    function () {
        var iv = this.i.rs();
        return (iv);
    };
    Object.defineProperty(IgxFinancialChartComponent.prototype, "applyCustomIndicators", {
        get: /**
             * Event raised by the chart when custom indicator data is needed from the application.
             * During series rendering, event will be raised once for each value in the CustomIndicatorNames collection.
            */
        function () {
            var _this = this;
            if (this._applyCustomIndicators == null) {
                this._applyCustomIndicators = new EventEmitter();
                this.i.applyCustomIndicators = delegateCombine(this.i.applyCustomIndicators, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new FinancialChartCustomIndicatorArgs();
                        outerArgs._provideImplementation(e);
                        _this._applyCustomIndicators.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._applyCustomIndicators;
        },
        enumerable: true,
        configurable: true
    });
    IgxFinancialChartComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-financial-chart',
                    template: "\n    <ng-template #financialChartTemplate>\n        <div class='financialChartMainGrid'>\n\t\t    <div class='financialChartToolbar'></div>\n\t\t    <div class='financialChartPrice'></div>\n\t\t    <div class='financialChartIndicators'></div>\n\t\t    <div class='financialChartVolume'></div>\n\t\t    <div class='financialChartZoomSlider'></div>\n\t    </div>\n    </ng-template>\n\n    <ng-container #dynamicContent></ng-container>\n    <igx-financial-chart-default-templates #defaultTemplates></igx-financial-chart-default-templates>\n    <igx-template-content #toolbarContent style=\"display: none\"></igx-template-content>\n\t<igx-template-content\n\t\tstyle=\"width: 100%; height: 100%\"\n\t\t#mainContent [template]=\"chartTemplate ? chartTemplate : financialChartTemplate\"></igx-template-content>",
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    providers: IgxFinancialChartComponent_PROVIDERS,
                    styles: ["\n\t\t:host {\n\t\t\tdisplay: block;\n\t\t}\n        .financialChartToolbar {\n            grid-row: 1;\n            -ms-grid-row: 1;\n        }\n        .financialChartPrice {\n            grid-row: 2;\n            -ms-grid-row: 2;\n        }\n        .financialChartIndicators {\n            grid-row: 3;\n            -ms-grid-row: 3;\n        }\n        .financialChartVolume {\n            grid-row: 4;\n            -ms-grid-row: 4;\n        }\n        .financialChartZoomSlider {\n            grid-row: 5;\n            -ms-grid-row: 5;\n        }\n\t\t.financialChartMainGrid {\n\t\t\theight: 100%;\n\t\t\twidth: 100%;\n\t\t\tdisplay: grid;\n\t\t\tdisplay: -ms-grid;\n\t\t\t-ms-grid-columns: 100%;\n\t\t}\n\t"],
                    host: {
                        '(document:click)': 'onDocumentClick($event)'
                    }
                },] },
    ];
    /** @nocollapse */
    IgxFinancialChartComponent.ctorParameters = function () { return [
        { type: Renderer2, },
        { type: ViewContainerRef, },
        { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
        { type: NgZone, },
        { type: Injector, },
        { type: ComponentFactoryResolver, },
    ]; };
    IgxFinancialChartComponent.propDecorators = {
        "_dynamicContent": [{ type: ViewChild, args: ["dynamicContent", { read: ViewContainerRef },] },],
        "_defaultTemplates": [{ type: ViewChild, args: [IgxFinancialChartDefaultTemplatesComponent,] },],
        "_templates": [{ type: ViewChildren, args: [IgxTemplateContentComponent,] },],
        "_toolbarElement": [{ type: ViewChild, args: ['toolbarContent', { read: ElementRef },] },],
        "_mainElement": [{ type: ViewChild, args: ['mainContent', { read: ElementRef },] },],
        "height": [{ type: Input },],
        "width": [{ type: Input },],
        "rangeSelectorTemplate": [{ type: Input },],
        "trendlinePickerTemplate": [{ type: Input },],
        "overlayPickerTemplate": [{ type: Input },],
        "chartTypePickerTemplate": [{ type: Input },],
        "volumeTypePickerTemplate": [{ type: Input },],
        "indicatorPickerTemplate": [{ type: Input },],
        "toolbarTemplate": [{ type: Input },],
        "chartTemplate": [{ type: Input },],
        "dataSource": [{ type: Input },],
        "leftMargin": [{ type: Input },],
        "isHorizontalZoomEnabled": [{ type: Input },],
        "toolbarHeight": [{ type: Input },],
        "yAxisIsLogarithmic": [{ type: Input },],
        "yAxisLogarithmBase": [{ type: Input },],
        "yAxisInterval": [{ type: Input },],
        "yAxisMinimumValue": [{ type: Input },],
        "yAxisMaximumValue": [{ type: Input },],
        "yAxisMinorInterval": [{ type: Input },],
        "volumeType": [{ type: Input },],
        "xAxisMode": [{ type: Input },],
        "yAxisMode": [{ type: Input },],
        "isToolbarVisible": [{ type: Input },],
        "chartType": [{ type: Input },],
        "yAxisLabelHorizontalAlignment": [{ type: Input },],
        "isWindowSyncedToVisibleRange": [{ type: Input },],
        "indicatorTypes": [{ type: Input },],
        "overlayTypes": [{ type: Input },],
        "yAxisAbbreviateLargeNumbers": [{ type: Input },],
        "resolution": [{ type: Input },],
        "yAxisLabelLocation": [{ type: Input },],
        "zoomSliderType": [{ type: Input },],
        "negativeBrushes": [{ type: Input },],
        "negativeOutlines": [{ type: Input },],
        "overlayBrushes": [{ type: Input },],
        "overlayOutlines": [{ type: Input },],
        "volumeOutlines": [{ type: Input },],
        "volumeBrushes": [{ type: Input },],
        "indicatorNegativeBrushes": [{ type: Input },],
        "indicatorBrushes": [{ type: Input },],
        "volumeThickness": [{ type: Input },],
        "overlayThickness": [{ type: Input },],
        "indicatorThickness": [{ type: Input },],
        "indicatorDisplayTypes": [{ type: Input },],
        "indicatorPeriod": [{ type: Input },],
        "indicatorMultiplier": [{ type: Input },],
        "indicatorSmoothingPeriod": [{ type: Input },],
        "indicatorShortPeriod": [{ type: Input },],
        "indicatorLongPeriod": [{ type: Input },],
        "indicatorSignalPeriod": [{ type: Input },],
        "rangeSelectorOptions": [{ type: Input },],
        "customIndicatorNames": [{ type: Input },],
        "isVerticalZoomEnabled": [{ type: Input },],
        "applyCustomIndicators": [{ type: Output },],
    };
    return IgxFinancialChartComponent;
}(IgxXYChartComponent));
export { IgxFinancialChartComponent };
//# sourceMappingURL=igx-financial-chart-component.js.map