import { Type } from '@angular/core';
import { IgxRect } from './IgxRect';
import { IgxPoint } from './IgxPoint';
import { IndicatorDisplayType } from './IndicatorDisplayType';
import { TrendLineType } from './TrendLineType';
import { IgxFinancialSeriesComponent } from './igx-financial-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { FinancialIndicator } from "./FinancialIndicator";
/**
 * Represents the base functionality for a IgxDataChartComponent financial indicator series.
*/
export declare const IgxFinancialIndicatorComponent_PROVIDERS: ({
    provide: typeof IgxFinancialSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare abstract class IgxFinancialIndicatorComponent extends IgxFinancialSeriesComponent {
    readonly i: FinancialIndicator;
    constructor();
    /**
     * Gets or sets the display for the current FinancialIndicator object.
    */
    displayType: IndicatorDisplayType;
    /**
     * Gets or sets the number of values to hide at the beginning of the indicator.
    */
    ignoreFirst: number;
    /**
     * Gets or sets the trend type for the current indicator series.
    */
    trendLineType: TrendLineType;
    /**
     * Gets or sets the brush to use to draw the trend line.
    */
    trendLineBrush: string;
    /**
     * Gets the effective TrendLineBrush for this indicator.
    */
    readonly actualTrendLineBrush: string;
    /**
     * Gets or sets the thickness of the current indicator object's trend line.
    */
    trendLineThickness: number;
    /**
     * Gets or sets the trend line period for the current series.
     * The typical, and initial, value for trend line period is 7.
    */
    trendLinePeriod: number;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgxPoint): IgxRect;
    getSeriesValue(world: IgxPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgxPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgxPoint, skipUnknowns: boolean): number;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
}
