import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { TrendLineType, TrendLineType_$type } from './TrendLineType';
import { PriceDisplayType, PriceDisplayType_$type } from './PriceDisplayType';
import { IgxFinancialSeriesComponent } from './igx-financial-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { FinancialPriceSeries } from "./FinancialPriceSeries";
import { ensureEnum, brushToString, stringToBrush, toPoint, fromRect } from "./componentUtil";
/**
 * Represents a IgxDataChartComponent financial price series that renders as Candlestick or OHLC representations.
 * Default required members: Open, Low, High, Close
*/
export var IgxFinancialPriceSeriesComponent_PROVIDERS = [{ provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxFinancialPriceSeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxFinancialPriceSeriesComponent; }) }];
var IgxFinancialPriceSeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxFinancialPriceSeriesComponent, _super);
    function IgxFinancialPriceSeriesComponent() {
        return _super.call(this) || this;
    }
    IgxFinancialPriceSeriesComponent.prototype.createImplementation = function () {
        return new FinancialPriceSeries();
    };
    Object.defineProperty(IgxFinancialPriceSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialPriceSeriesComponent.prototype, "trendLineType", {
        /**
         * Gets or sets the trend type for the current financial series.
        */
        get: /**
             * Gets or sets the trend type for the current financial series.
            */
        function () {
            return this.i.trendLineType;
        },
        set: function (v) {
            this.i.trendLineType = ensureEnum(TrendLineType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialPriceSeriesComponent.prototype, "trendLineBrush", {
        /**
         * Gets or sets the brush to use to draw the trend line.
        */
        get: /**
             * Gets or sets the brush to use to draw the trend line.
            */
        function () {
            return brushToString(this.i.trendLineBrush);
        },
        set: function (v) {
            this.i.trendLineBrush = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialPriceSeriesComponent.prototype, "actualTrendLineBrush", {
        /**
         * Gets the effective TrendLineBrush for this FinancialPriceSeries.
        */
        get: /**
             * Gets the effective TrendLineBrush for this FinancialPriceSeries.
            */
        function () {
            return brushToString(this.i.pg);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialPriceSeriesComponent.prototype, "trendLineThickness", {
        /**
         * Gets or sets the thickness of the current FinancialPriceSeries object's trend line.
        */
        get: /**
             * Gets or sets the thickness of the current FinancialPriceSeries object's trend line.
            */
        function () {
            return this.i.trendLineThickness;
        },
        set: function (v) {
            this.i.trendLineThickness = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialPriceSeriesComponent.prototype, "trendLinePeriod", {
        /**
         * Gets or sets the trend line period for the current series.
         * The typical, and initial, value for trend line period is 7.
        */
        get: /**
             * Gets or sets the trend line period for the current series.
             * The typical, and initial, value for trend line period is 7.
            */
        function () {
            return this.i.trendLinePeriod;
        },
        set: function (v) {
            this.i.trendLinePeriod = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialPriceSeriesComponent.prototype, "displayType", {
        /**
         * Gets or sets the display type for the current FinancialPriceSeries object.
        */
        get: /**
             * Gets or sets the display type for the current FinancialPriceSeries object.
            */
        function () {
            return this.i.ox;
        },
        set: function (v) {
            this.i.ox = ensureEnum(PriceDisplayType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialPriceSeriesComponent.prototype, "negativeOutline", {
        /**
         * Brush to use for outlining negative elements in the series.
        */
        get: /**
             * Brush to use for outlining negative elements in the series.
            */
        function () {
            return brushToString(this.i.ph);
        },
        set: function (v) {
            this.i.ph = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    IgxFinancialPriceSeriesComponent.prototype.getSeriesValueBoundingBox = /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    function (world) {
        var iv = this.i.k9(toPoint(world));
        return fromRect(iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The categorySeries is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    /**
         * Scrolls the series to display the item for the specified data item.
         * The categorySeries is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    IgxFinancialPriceSeriesComponent.prototype.scrollIntoView = /**
         * Scrolls the series to display the item for the specified data item.
         * The categorySeries is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    function (item) {
        var iv = this.i.c5(item);
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
    IgxFinancialPriceSeriesComponent.prototype.getItemSpan = /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
    function () {
        var iv = this.i.d7();
        return (iv);
    };
    IgxFinancialPriceSeriesComponent.prototype.setNegativeColors = function (negativeBrush, negativeOutline) {
        this.i.iy(stringToBrush(negativeBrush), stringToBrush(negativeOutline));
    };
    IgxFinancialPriceSeriesComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-financial-price-series',
                    template: "",
                    providers: [{ provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxFinancialPriceSeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxFinancialPriceSeriesComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxFinancialPriceSeriesComponent.ctorParameters = function () { return []; };
    IgxFinancialPriceSeriesComponent.propDecorators = {
        "trendLineType": [{ type: Input },],
        "trendLineBrush": [{ type: Input },],
        "trendLineThickness": [{ type: Input },],
        "trendLinePeriod": [{ type: Input },],
        "displayType": [{ type: Input },],
        "negativeOutline": [{ type: Input },],
    };
    return IgxFinancialPriceSeriesComponent;
}(IgxFinancialSeriesComponent));
export { IgxFinancialPriceSeriesComponent };
//# sourceMappingURL=igx-financial-price-series-component.js.map