import { Type } from '@angular/core';
import { IgxRect } from './IgxRect';
import { IgxPoint } from './IgxPoint';
import { IgxCategoryAxisBaseComponent } from './igx-category-axis-base-component';
import { IgxNumericYAxisComponent } from './igx-numeric-y-axis-component';
import { IgxAnchoredCategorySeriesComponent } from './igx-anchored-category-series-component';
import { IgxMarkerSeriesComponent } from './igx-marker-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
export declare const IgxHorizontalAnchoredCategorySeriesComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
/**
 * Base class for anchored category series with a category x-axis and a numeric y-axis.
*/
export declare abstract class IgxHorizontalAnchoredCategorySeriesComponent extends IgxAnchoredCategorySeriesComponent {
    constructor();
    readonly i: HorizontalAnchoredCategorySeries;
    /**
 * Gets or sets the effective x-axis for this series.
*/
    xAxis: IgxCategoryAxisBaseComponent;
    /**
     * Gets or sets the effective y-axis for this series.
    */
    yAxis: IgxNumericYAxisComponent;
    /**
 * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.

* @param world  * The world coordinates for which to get a value marker bounding box for
*/
    getSeriesValueMarkerBoundingBox(world: IgxPoint): IgxRect;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    getSeriesValue(world: IgxPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgxPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgxPoint, skipUnknowns: boolean): number;
    getSeriesValuePosition(world: IgxPoint, useInterpolation: boolean, skipUnknowns: boolean): IgxPoint;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
}
