import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { HorizontalAlignment, HorizontalAlignment_$type } from './HorizontalAlignment';
import { VerticalAlignment, VerticalAlignment_$type } from './VerticalAlignment';
import { Visibility, Visibility_$type } from './Visibility';
import { AxisLabelsLocation, AxisLabelsLocation_$type } from './AxisLabelsLocation';
import { IgxDomainChartComponent } from './igx-domain-chart-component';
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "./componentUtil";
/**
 * Represents a base class for domain charts with X/Y axes
*/
export var IgxXYChartComponent_PROVIDERS = [{ provide: IgxDomainChartComponent, useExisting: forwardRef(function () { return IgxXYChartComponent; }) }];
var IgxXYChartComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxXYChartComponent, _super);
    function IgxXYChartComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxXYChartComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisFormatLabel", {
        /**
         * Gets or sets function which takes an context object and returns a formatted label for the X-axis.
        */
        get: /**
             * Gets or sets function which takes an context object and returns a formatted label for the X-axis.
            */
        function () {
            return this.i.gn;
        },
        set: function (v) {
            this.i.gn = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisFormatLabel", {
        /**
         * Gets or sets function which takes a context object and returns a formatted label for the Y-axis.
        */
        get: /**
             * Gets or sets function which takes a context object and returns a formatted label for the Y-axis.
            */
        function () {
            return this.i.go;
        },
        set: function (v) {
            this.i.go = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelLeftMargin", {
        /**
         * Gets or sets the left margin of labels on the X-axis
        */
        get: /**
             * Gets or sets the left margin of labels on the X-axis
            */
        function () {
            return this.i.h0;
        },
        set: function (v) {
            this.i.h0 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelTopMargin", {
        /**
         * Gets or sets the top margin of labels on the X-axis
        */
        get: /**
             * Gets or sets the top margin of labels on the X-axis
            */
        function () {
            return this.i.h2;
        },
        set: function (v) {
            this.i.h2 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelRightMargin", {
        /**
         * Gets or sets the right margin of labels on the X-axis
        */
        get: /**
             * Gets or sets the right margin of labels on the X-axis
            */
        function () {
            return this.i.h1;
        },
        set: function (v) {
            this.i.h1 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelBottomMargin", {
        /**
         * Gets or sets the bottom margin of labels on the X-axis
        */
        get: /**
             * Gets or sets the bottom margin of labels on the X-axis
            */
        function () {
            return this.i.hz;
        },
        set: function (v) {
            this.i.hz = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelLeftMargin", {
        /**
         * Gets or sets the left margin of labels on the Y-axis
        */
        get: /**
             * Gets or sets the left margin of labels on the Y-axis
            */
        function () {
            return this.i.ii;
        },
        set: function (v) {
            this.i.ii = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelTopMargin", {
        /**
         * Gets or sets the top margin of labels on the Y-axis
        */
        get: /**
             * Gets or sets the top margin of labels on the Y-axis
            */
        function () {
            return this.i.ik;
        },
        set: function (v) {
            this.i.ik = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelRightMargin", {
        /**
         * Gets or sets the right margin of labels on the Y-axis
        */
        get: /**
             * Gets or sets the right margin of labels on the Y-axis
            */
        function () {
            return this.i.ij;
        },
        set: function (v) {
            this.i.ij = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelBottomMargin", {
        /**
         * Gets or sets the bottom margin of labels on the Y-axis
        */
        get: /**
             * Gets or sets the bottom margin of labels on the Y-axis
            */
        function () {
            return this.i.ih;
        },
        set: function (v) {
            this.i.ih = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelTextColor", {
        /**
         * Gets or sets color of labels on the X-axis
        */
        get: /**
             * Gets or sets color of labels on the X-axis
            */
        function () {
            return brushToString(this.i.l8);
        },
        set: function (v) {
            this.i.l8 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelTextColor", {
        /**
         * Gets or sets color of labels on the Y-axis
        */
        get: /**
             * Gets or sets color of labels on the Y-axis
            */
        function () {
            return brushToString(this.i.mf);
        },
        set: function (v) {
            this.i.mf = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleMargin", {
        /**
         * Gets or sets the margin around a title on the X-axis
        */
        get: /**
             * Gets or sets the margin around a title on the X-axis
            */
        function () {
            return this.i.ib;
        },
        set: function (v) {
            this.i.ib = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleMargin", {
        /**
         * Gets or sets the margin around a title on the Y-axis
        */
        get: /**
             * Gets or sets the margin around a title on the Y-axis
            */
        function () {
            return this.i.iu;
        },
        set: function (v) {
            this.i.iu = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleLeftMargin", {
        /**
         * Gets or sets the left margin of a title on the X-axis
        */
        get: /**
             * Gets or sets the left margin of a title on the X-axis
            */
        function () {
            return this.i.ia;
        },
        set: function (v) {
            this.i.ia = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleLeftMargin", {
        /**
         * Gets or sets the left margin of a title on the Y-axis
        */
        get: /**
             * Gets or sets the left margin of a title on the Y-axis
            */
        function () {
            return this.i.it;
        },
        set: function (v) {
            this.i.it = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleTopMargin", {
        /**
         * Gets or sets the top margin of a title on the X-axis
        */
        get: /**
             * Gets or sets the top margin of a title on the X-axis
            */
        function () {
            return this.i.id;
        },
        set: function (v) {
            this.i.id = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleTopMargin", {
        /**
         * Gets or sets the top margin of a title on the Y-axis
        */
        get: /**
             * Gets or sets the top margin of a title on the Y-axis
            */
        function () {
            return this.i.iw;
        },
        set: function (v) {
            this.i.iw = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleRightMargin", {
        /**
         * Gets or sets the right margin of a title on the X-axis
        */
        get: /**
             * Gets or sets the right margin of a title on the X-axis
            */
        function () {
            return this.i.ic;
        },
        set: function (v) {
            this.i.ic = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleRightMargin", {
        /**
         * Gets or sets the right margin of a title on the Y-axis
        */
        get: /**
             * Gets or sets the right margin of a title on the Y-axis
            */
        function () {
            return this.i.iv;
        },
        set: function (v) {
            this.i.iv = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleBottomMargin", {
        /**
         * Gets or sets the bottom margin of a title on the X-axis
        */
        get: /**
             * Gets or sets the bottom margin of a title on the X-axis
            */
        function () {
            return this.i.h9;
        },
        set: function (v) {
            this.i.h9 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleBottomMargin", {
        /**
         * Gets or sets the bottom margin of a title on the Y-axis
        */
        get: /**
             * Gets or sets the bottom margin of a title on the Y-axis
            */
        function () {
            return this.i.is;
        },
        set: function (v) {
            this.i.is = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleTextColor", {
        /**
         * Gets or sets color of title on the X-axis
        */
        get: /**
             * Gets or sets color of title on the X-axis
            */
        function () {
            return brushToString(this.i.me);
        },
        set: function (v) {
            this.i.me = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleTextColor", {
        /**
         * Gets or sets color of title on the Y-axis
        */
        get: /**
             * Gets or sets color of title on the Y-axis
            */
        function () {
            return brushToString(this.i.ml);
        },
        set: function (v) {
            this.i.ml = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelTextStyle", {
        /**
         * Gets or sets CSS font property for labels on X-axis
        */
        get: /**
             * Gets or sets CSS font property for labels on X-axis
            */
        function () {
            return this.i.ji;
        },
        set: function (v) {
            this.i.ji = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelTextStyle", {
        /**
         * Gets or sets CSS font property for labels on Y-axis
        */
        get: /**
             * Gets or sets CSS font property for labels on Y-axis
            */
        function () {
            return this.i.kk;
        },
        set: function (v) {
            this.i.kk = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleTextStyle", {
        /**
         * Gets or sets CSS font property for title on X-axis
        */
        get: /**
             * Gets or sets CSS font property for title on X-axis
            */
        function () {
            return this.i.j6;
        },
        set: function (v) {
            this.i.j6 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleTextStyle", {
        /**
         * Gets or sets CSS font property for title on Y-axis
        */
        get: /**
             * Gets or sets CSS font property for title on Y-axis
            */
        function () {
            return this.i.k8;
        },
        set: function (v) {
            this.i.k8 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabel", {
        /**
         * Gets or sets the format for labels along the X-axis.
        */
        get: /**
             * Gets or sets the format for labels along the X-axis.
            */
        function () {
            return this.i.iz;
        },
        set: function (v) {
            this.i.iz = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabel", {
        /**
         * Gets or sets the format for labels along the Y-axis.
        */
        get: /**
             * Gets or sets the format for labels along the Y-axis.
            */
        function () {
            return this.i.i0;
        },
        set: function (v) {
            this.i.i0 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisMajorStroke", {
        /**
         * Gets or sets the color to apply to major gridlines along the X-axis.
        */
        get: /**
             * Gets or sets the color to apply to major gridlines along the X-axis.
            */
        function () {
            return brushToString(this.i.l9);
        },
        set: function (v) {
            this.i.l9 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisMajorStroke", {
        /**
         * Gets or sets the color to apply to major gridlines along the Y-axis.
        */
        get: /**
             * Gets or sets the color to apply to major gridlines along the Y-axis.
            */
        function () {
            return brushToString(this.i.mg);
        },
        set: function (v) {
            this.i.mg = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisMajorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to major gridlines along the X-axis.
        */
        get: /**
             * Gets or sets the thickness to apply to major gridlines along the X-axis.
            */
        function () {
            return this.i.h3;
        },
        set: function (v) {
            this.i.h3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisMajorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to major gridlines along the Y-axis.
        */
        get: /**
             * Gets or sets the thickness to apply to major gridlines along the Y-axis.
            */
        function () {
            return this.i.il;
        },
        set: function (v) {
            this.i.il = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisMinorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to minor gridlines along the X-axis.
        */
        get: /**
             * Gets or sets the thickness to apply to minor gridlines along the X-axis.
            */
        function () {
            return this.i.h4;
        },
        set: function (v) {
            this.i.h4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisMinorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to minor gridlines along the Y-axis.
        */
        get: /**
             * Gets or sets the thickness to apply to minor gridlines along the Y-axis.
            */
        function () {
            return this.i.im;
        },
        set: function (v) {
            this.i.im = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisStrip", {
        /**
         * Gets or sets the color to apply to stripes along the X-axis.
        */
        get: /**
             * Gets or sets the color to apply to stripes along the X-axis.
            */
        function () {
            return brushToString(this.i.mb);
        },
        set: function (v) {
            this.i.mb = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisStrip", {
        /**
         * Gets or sets the color to apply to stripes along the Y-axis.
        */
        get: /**
             * Gets or sets the color to apply to stripes along the Y-axis.
            */
        function () {
            return brushToString(this.i.mi);
        },
        set: function (v) {
            this.i.mi = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisStroke", {
        /**
         * Gets or sets the color to apply to the X-axis line.
        */
        get: /**
             * Gets or sets the color to apply to the X-axis line.
            */
        function () {
            return brushToString(this.i.mc);
        },
        set: function (v) {
            this.i.mc = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisStroke", {
        /**
         * Gets or sets the color to apply to the Y-axis line.
        */
        get: /**
             * Gets or sets the color to apply to the Y-axis line.
            */
        function () {
            return brushToString(this.i.mj);
        },
        set: function (v) {
            this.i.mj = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to the X-axis line.
        */
        get: /**
             * Gets or sets the thickness to apply to the X-axis line.
            */
        function () {
            return this.i.h5;
        },
        set: function (v) {
            this.i.h5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to the Y-axis line.
        */
        get: /**
             * Gets or sets the thickness to apply to the Y-axis line.
            */
        function () {
            return this.i.io;
        },
        set: function (v) {
            this.i.io = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTickLength", {
        /**
         * Gets or sets the length of tickmarks along the X-axis.
        */
        get: /**
             * Gets or sets the length of tickmarks along the X-axis.
            */
        function () {
            return this.i.h6;
        },
        set: function (v) {
            this.i.h6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTickLength", {
        /**
         * Gets or sets the length of tickmarks along the Y-axis.
        */
        get: /**
             * Gets or sets the length of tickmarks along the Y-axis.
            */
        function () {
            return this.i.ip;
        },
        set: function (v) {
            this.i.ip = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTickStroke", {
        /**
         * Gets or sets the color to apply to tickmarks along the X-axis.
        */
        get: /**
             * Gets or sets the color to apply to tickmarks along the X-axis.
            */
        function () {
            return brushToString(this.i.md);
        },
        set: function (v) {
            this.i.md = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTickStroke", {
        /**
         * Gets or sets the color to apply to tickmarks along the Y-axis.
        */
        get: /**
             * Gets or sets the color to apply to tickmarks along the Y-axis.
            */
        function () {
            return brushToString(this.i.mk);
        },
        set: function (v) {
            this.i.mk = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTickStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to tickmarks along the X-axis.
        */
        get: /**
             * Gets or sets the thickness to apply to tickmarks along the X-axis.
            */
        function () {
            return this.i.h7;
        },
        set: function (v) {
            this.i.h7 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTickStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to tickmarks along the Y-axis.
        */
        get: /**
             * Gets or sets the thickness to apply to tickmarks along the Y-axis.
            */
        function () {
            return this.i.iq;
        },
        set: function (v) {
            this.i.iq = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitle", {
        /**
         * Gets or sets the Text to display below the X-axis.
        */
        get: /**
             * Gets or sets the Text to display below the X-axis.
            */
        function () {
            return this.i.jx;
        },
        set: function (v) {
            this.i.jx = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitle", {
        /**
         * Gets or sets the Text to display to the left of the Y-axis.
        */
        get: /**
             * Gets or sets the Text to display to the left of the Y-axis.
            */
        function () {
            return this.i.kz;
        },
        set: function (v) {
            this.i.kz = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisMinorStroke", {
        /**
         * Gets or sets the color to apply to minor gridlines along the X-axis.
        */
        get: /**
             * Gets or sets the color to apply to minor gridlines along the X-axis.
            */
        function () {
            return brushToString(this.i.ma);
        },
        set: function (v) {
            this.i.ma = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisMinorStroke", {
        /**
         * Gets or sets the color to apply to minor gridlines along the Y-axis.
        */
        get: /**
             * Gets or sets the color to apply to minor gridlines along the Y-axis.
            */
        function () {
            return brushToString(this.i.mh);
        },
        set: function (v) {
            this.i.mh = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelAngle", {
        /**
         * Gets or sets the angle of rotation for labels along the X-axis.
        */
        get: /**
             * Gets or sets the angle of rotation for labels along the X-axis.
            */
        function () {
            return this.i.hy;
        },
        set: function (v) {
            this.i.hy = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelAngle", {
        /**
         * Gets or sets the angle of rotation for labels along the Y-axis.
        */
        get: /**
             * Gets or sets the angle of rotation for labels along the Y-axis.
            */
        function () {
            return this.i.ig;
        },
        set: function (v) {
            this.i.ig = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisExtent", {
        /**
         * Gets or sets the distance between the X-axis and the bottom of the chart.
        */
        get: /**
             * Gets or sets the distance between the X-axis and the bottom of the chart.
            */
        function () {
            return this.i.hx;
        },
        set: function (v) {
            this.i.hx = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisExtent", {
        /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        */
        get: /**
             * Gets or sets the distance between the Y-axis and the left edge of the chart.
            */
        function () {
            return this.i.ie;
        },
        set: function (v) {
            this.i.ie = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleAngle", {
        /**
         * Gets or sets the angle of rotation for the X-axis title.
        */
        get: /**
             * Gets or sets the angle of rotation for the X-axis title.
            */
        function () {
            return this.i.h8;
        },
        set: function (v) {
            this.i.h8 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleAngle", {
        /**
         * Gets or sets the angle of rotation for the Y-axis title.
        */
        get: /**
             * Gets or sets the angle of rotation for the Y-axis title.
            */
        function () {
            return this.i.ir;
        },
        set: function (v) {
            this.i.ir = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisInverted", {
        /**
         * Gets or sets whether to invert the direction of the X-axis by placing the first data items on the right side of the chart.
        */
        get: /**
             * Gets or sets whether to invert the direction of the X-axis by placing the first data items on the right side of the chart.
            */
        function () {
            return this.i.gt;
        },
        set: function (v) {
            this.i.gt = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisInverted", {
        /**
         * Gets or sets whether to invert the direction of the Y-axis by placing the minimum numeric value at the top of the chart.
        *
        * You can use `YAxisInverted` to invert the scale of the y axis like this:
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisInverted="true"
        * >
        *
        * </igx-category-chart>
        * ```
        *
        * The default value of `YAxisInverted` is false.
        */
        get: /**
             * Gets or sets whether to invert the direction of the Y-axis by placing the minimum numeric value at the top of the chart.
            *
            * You can use `YAxisInverted` to invert the scale of the y axis like this:
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisInverted="true"
            * >
            *
            * </igx-category-chart>
            * ```
            *
            * The default value of `YAxisInverted` is false.
            */
        function () {
            return this.i.gu;
        },
        set: function (v) {
            this.i.gu = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleAlignment", {
        /**
         * Gets or sets Horizontal alignment of the X-axis title.
        */
        get: /**
             * Gets or sets Horizontal alignment of the X-axis title.
            */
        function () {
            return this.i.ls;
        },
        set: function (v) {
            this.i.ls = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleAlignment", {
        /**
         * Gets or sets Vertical alignment of the Y-axis title.
        */
        get: /**
             * Gets or sets Vertical alignment of the Y-axis title.
            */
        function () {
            return this.i.mr;
        },
        set: function (v) {
            this.i.mr = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelHorizontalAlignment", {
        /**
         * Gets or sets Horizontal alignment of X-axis labels.
        */
        get: /**
             * Gets or sets Horizontal alignment of X-axis labels.
            */
        function () {
            return this.i.lr;
        },
        set: function (v) {
            this.i.lr = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelHorizontalAlignment", {
        /**
         * Gets or sets Horizontal alignment of Y-axis labels.
        */
        get: /**
             * Gets or sets Horizontal alignment of Y-axis labels.
            */
        function () {
            return this.i.lt;
        },
        set: function (v) {
            this.i.lt = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelVerticalAlignment", {
        /**
         * Gets or sets Vertical alignment of X-axis labels.
        */
        get: /**
             * Gets or sets Vertical alignment of X-axis labels.
            */
        function () {
            return this.i.mp;
        },
        set: function (v) {
            this.i.mp = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelVerticalAlignment", {
        /**
         * Gets or sets Vertical alignment of Y-axis labels.
        */
        get: /**
             * Gets or sets Vertical alignment of Y-axis labels.
            */
        function () {
            return this.i.mq;
        },
        set: function (v) {
            this.i.mq = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelVisibility", {
        /**
         * Gets or sets Visibility of X-axis labels.
        */
        get: /**
             * Gets or sets Visibility of X-axis labels.
            */
        function () {
            return this.i.mu;
        },
        set: function (v) {
            this.i.mu = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelVisibility", {
        /**
         * Gets or sets Visibility of Y-axis labels.
        */
        get: /**
             * Gets or sets Visibility of Y-axis labels.
            */
        function () {
            return this.i.mv;
        },
        set: function (v) {
            this.i.mv = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelLocation", {
        /**
         * The location of Y-axis labels, relative to the plot area.
        */
        get: /**
             * The location of Y-axis labels, relative to the plot area.
            */
        function () {
            return this.i.gq;
        },
        set: function (v) {
            this.i.gq = ensureEnum(AxisLabelsLocation_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Converts the given visual location to a data value.
    
    * @param unscaledValue  * The x-coordinate of the location to scale.
    */
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    IgxXYChartComponent.prototype.getScaledValueX = /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    function (unscaledValue) {
        var iv = this.i.ht(unscaledValue);
        return (iv);
    };
    /**
     * Converts the given data value to a visual location.
    
    * @param scaledValue  * The data value to un-scale.
    */
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    IgxXYChartComponent.prototype.getUnscaledValueX = /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    function (scaledValue) {
        var iv = this.i.hv(scaledValue);
        return (iv);
    };
    /**
     * Converts the given visual location to a data value.
    
    * @param unscaledValue  * The y-coordinate of the location to scale.
    */
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    IgxXYChartComponent.prototype.getScaledValueY = /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    function (unscaledValue) {
        var iv = this.i.hu(unscaledValue);
        return (iv);
    };
    /**
     * Converts the given data value to a visual location.
    
    * @param scaledValue  * The data value to un-scale.
    */
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    IgxXYChartComponent.prototype.getUnscaledValueY = /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    function (scaledValue) {
        var iv = this.i.hw(scaledValue);
        return (iv);
    };
    IgxXYChartComponent.propDecorators = {
        "xAxisFormatLabel": [{ type: Input },],
        "yAxisFormatLabel": [{ type: Input },],
        "xAxisLabelLeftMargin": [{ type: Input },],
        "xAxisLabelTopMargin": [{ type: Input },],
        "xAxisLabelRightMargin": [{ type: Input },],
        "xAxisLabelBottomMargin": [{ type: Input },],
        "yAxisLabelLeftMargin": [{ type: Input },],
        "yAxisLabelTopMargin": [{ type: Input },],
        "yAxisLabelRightMargin": [{ type: Input },],
        "yAxisLabelBottomMargin": [{ type: Input },],
        "xAxisLabelTextColor": [{ type: Input },],
        "yAxisLabelTextColor": [{ type: Input },],
        "xAxisTitleMargin": [{ type: Input },],
        "yAxisTitleMargin": [{ type: Input },],
        "xAxisTitleLeftMargin": [{ type: Input },],
        "yAxisTitleLeftMargin": [{ type: Input },],
        "xAxisTitleTopMargin": [{ type: Input },],
        "yAxisTitleTopMargin": [{ type: Input },],
        "xAxisTitleRightMargin": [{ type: Input },],
        "yAxisTitleRightMargin": [{ type: Input },],
        "xAxisTitleBottomMargin": [{ type: Input },],
        "yAxisTitleBottomMargin": [{ type: Input },],
        "xAxisTitleTextColor": [{ type: Input },],
        "yAxisTitleTextColor": [{ type: Input },],
        "xAxisLabelTextStyle": [{ type: Input },],
        "yAxisLabelTextStyle": [{ type: Input },],
        "xAxisTitleTextStyle": [{ type: Input },],
        "yAxisTitleTextStyle": [{ type: Input },],
        "xAxisLabel": [{ type: Input },],
        "yAxisLabel": [{ type: Input },],
        "xAxisMajorStroke": [{ type: Input },],
        "yAxisMajorStroke": [{ type: Input },],
        "xAxisMajorStrokeThickness": [{ type: Input },],
        "yAxisMajorStrokeThickness": [{ type: Input },],
        "xAxisMinorStrokeThickness": [{ type: Input },],
        "yAxisMinorStrokeThickness": [{ type: Input },],
        "xAxisStrip": [{ type: Input },],
        "yAxisStrip": [{ type: Input },],
        "xAxisStroke": [{ type: Input },],
        "yAxisStroke": [{ type: Input },],
        "xAxisStrokeThickness": [{ type: Input },],
        "yAxisStrokeThickness": [{ type: Input },],
        "xAxisTickLength": [{ type: Input },],
        "yAxisTickLength": [{ type: Input },],
        "xAxisTickStroke": [{ type: Input },],
        "yAxisTickStroke": [{ type: Input },],
        "xAxisTickStrokeThickness": [{ type: Input },],
        "yAxisTickStrokeThickness": [{ type: Input },],
        "xAxisTitle": [{ type: Input },],
        "yAxisTitle": [{ type: Input },],
        "xAxisMinorStroke": [{ type: Input },],
        "yAxisMinorStroke": [{ type: Input },],
        "xAxisLabelAngle": [{ type: Input },],
        "yAxisLabelAngle": [{ type: Input },],
        "xAxisExtent": [{ type: Input },],
        "yAxisExtent": [{ type: Input },],
        "xAxisTitleAngle": [{ type: Input },],
        "yAxisTitleAngle": [{ type: Input },],
        "xAxisInverted": [{ type: Input },],
        "yAxisInverted": [{ type: Input },],
        "xAxisTitleAlignment": [{ type: Input },],
        "yAxisTitleAlignment": [{ type: Input },],
        "xAxisLabelHorizontalAlignment": [{ type: Input },],
        "yAxisLabelHorizontalAlignment": [{ type: Input },],
        "xAxisLabelVerticalAlignment": [{ type: Input },],
        "yAxisLabelVerticalAlignment": [{ type: Input },],
        "xAxisLabelVisibility": [{ type: Input },],
        "yAxisLabelVisibility": [{ type: Input },],
        "yAxisLabelLocation": [{ type: Input },],
    };
    return IgxXYChartComponent;
}(IgxDomainChartComponent));
export { IgxXYChartComponent };
//# sourceMappingURL=igx-xy-chart-component.js.map